@@ -621,31 +621,32 @@ class Map(Base):
         grid_settings = {'enable_grid', 'grid_unit', 'grid_width', 'grid_height', 'grid_minzoom', 'grid_maxzoom'}
         view_settings = {'bearing', 'pitch', 'center', 'zoom'}
 
+        settings = self.settings
+
         for key, value in kwargs.items():
             if key in general_settings:
-                self.settings['general_settings'][key] = value
+                settings['general_settings'][key] = value
             elif key in edit_settings:
-                self.settings['edit_settings'][key] = value
+                settings['edit_settings'][key] = value
             elif key in snap_settings:
-                self.settings['snap_settings'][key] = value
+                settings['snap_settings'][key] = value
             elif key == 'controls':
-                self.settings['controls'] = value
+                settings['controls'] = value
             elif key in search_settings:
-                self.settings['search_settings'][key] = value
+                settings['search_settings'][key] = value
             elif key in marker_settings:
-                self.settings['marker_settings'][key] = value
+                settings['marker_settings'][key] = value
             elif key in terrain_settings:
-                self.settings['terrain_settings'][key] = value
+                settings['terrain_settings'][key] = value
             elif key in grid_settings:
-                self.settings['grid_settings'][key] = value
+                settings['grid_settings'][key] = value
             elif key in view_settings:
-                self.settings['view_settings'][key] = value
+                settings['view_settings'][key] = value
             elif key == 'toc_settings':
-                self.settings['toc_settings'] = value
+                settings['toc_settings'] = value
+
+        return super()._set_settings(self.endpoint, settings)    
 
-        endpoint = urljoin(self.endpoint, 'settings/')
-        self.api.put(endpoint, self.settings)
-    
 
     def get_markers(self) -> Dict:
         """
