@@ -295,7 +295,7 @@ class Mosaic(Raster):
         return super().get_point(lat, lng)
 
 
-    def get_tile_render_url(self, x: int, y: int, z: int) -> str:
+    def get_render_png_url(self, x: int, y: int, z: int, **kwargs) -> str:
         """
         Get the tile render URL of the mosaic.
 
@@ -304,6 +304,15 @@ class Mosaic(Raster):
             y (int): The y coordinate of the tile.
             z (int): The zoom level of the tile.
 
+        Keyword Args:
+            indexes (str, optional): list of comma separated band indexes to be rendered. e.g. 1, 2, 3
+            nodata (int, optional)
+            expression (str, optional): band math expression. e.g. b1*b2+b3
+            rescale (List, optional): comma (',') separated Min,Max range. Can set multiple time for multiple bands.
+            color_formula (str, optional): Color formula. e.g. gamma R 0.5
+            colormap_name (str, optional)
+            colormap (str, optional): JSON encoded custom Colormap. e.g. {"0": "#ff0000", "1": "#00ff00"} or [[[0, 100], "#ff0000"], [[100, 200], "#00ff00"]]
+
         Returns:
             str: The tile render URL of the mosaic.
 
@@ -314,7 +323,7 @@ class Mosaic(Raster):
             >>> mosaic = Mosaic.get_mosaic(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> mosaic.get_tile_render_url(x=1, y=1, z=1)
         """
-        return super().get_tile_render_url(x, y, z)
+        return super().get_render_png_url(x, y, z, **kwargs)
     
 
     def get_tile_png_url(self, x: int, y: int, z: int) -> str:
