@@ -582,7 +582,7 @@ class Query(Base):
         super()._unshare(self.endpoint, users)
 
 
-    def get_shared_users(self, search: str, skip: int = 0, limit: int = 10) -> List['User']:
+    def get_shared_users(self, search: str = None, skip: int = 0, limit: int = 10) -> List['User']:
         """
         Retrieves the list of users the query is shared with.
 
@@ -624,18 +624,16 @@ class Query(Base):
         return endpoint
 
 
-    def save_as_layer(self, layer_name: str, layer_type: 'QueryGeometryType') -> Dict:
+    def save_as_layer(self, layer_name: str, layer_type: 'QueryGeometryType' = None) -> Task:
         """
         Saves the query as a new layer.
 
         Args:
-            sql (str): The SQL statement for the query.
-            params (list): The parameters for the SQL statement.
             layer_name (str): The name of the new layer.
-            layer_type (QueryGeometryType): The type of the new layer.
+            layer_type (QueryGeometryType, optional): The type of the new layer.
 
         Returns:
-            Dict: The response from the API.
+            Task: The response task object.
             
         Raises:
             PermissionError: If the query is a read-only system query.
@@ -645,7 +643,7 @@ class Query(Base):
             >>> from geobox.query import Query
             >>> client = GeoboxClient()
             >>> query = Query.get_query(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> query.save_as_layer(layer_name='test', layer_type=QueryGeometryType.POLYGON)
+            >>> query.save_as_layer(layer_name='test')
         """
         self._check_access()
 
@@ -659,7 +657,7 @@ class Query(Base):
             "sql": self.sql,
             "params": params,
             "layer_name": layer_name,
-            "layer_type": layer_type.value
+            "layer_type": layer_type.value if layer_type else None
         })
 
         endpoint = urljoin(self.BASE_ENDPOINT, 'saveAsLayer/')
