@@ -3,6 +3,7 @@ from urllib.parse import urljoin, urlencode
 from typing import Optional, Dict, List, Optional, Union, TYPE_CHECKING
 import mimetypes
 import requests
+import sys
 
 from .base import Base
 from .utils import clean_data
@@ -179,7 +180,6 @@ class Raster(Base):
             name (str): The name of the raster.
             display_name (str): The display name of the raster.
             description (str): The description of the raster.
-            max_zoom (int): The max zoom of the raster.
 
         Returns:
             None
@@ -194,10 +194,9 @@ class Raster(Base):
         params = {
             'name': kwargs.get('name'),
             'display_name': kwargs.get('display_name'),
-            'description': kwargs.get('description'),
-            'max_zoom': kwargs.get('max_zoom'),
+            'description': kwargs.get('description')
         }
-        super()._update(self.endpoint, params)
+        return super()._update(self.endpoint, params)
     
 
     def delete(self) -> None:
@@ -236,7 +235,8 @@ class Raster(Base):
         return endpoint
     
     
-    def get_raster_info(self) -> Dict:
+    @property
+    def info(self) -> Dict:
         """
         Get the info of the raster.
 
@@ -248,7 +248,7 @@ class Raster(Base):
             >>> from geobox.raster import Raster
             >>> client = GeoboxClient()
             >>> raster = Raster.get_raster(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> raster.get_raster_info()
+            >>> raster.info
         """
         endpoint = urljoin(self.endpoint, 'info/')
         return self.api.get(endpoint)
@@ -323,53 +323,74 @@ class Raster(Base):
         
         Raises:
             ValueError: If save_path does not end with a '/'.
-        """
-        # Get the original filename from data or use uuid
-        if self.name:
-            filename = f"{self.name.split('.')[0]}" if len(self.name.split('.')) > 1 else f'{self.name}'
-        else:
-            filename = f'{self.uuid}'
 
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.file import File
+            >>> from geobox import GeoboxClient
+            >>> client = GeoboxClient()
+            >>> file_path = File.get_file(client, uuid="12345678-1234-5678-1234-567812345678")
+        """
         # If save_path is provided, check if it ends with a '/'
         if save_path and save_path.endswith('/'):
-            return f'{save_path}{filename}'
+            return f'{save_path}'
         
         if save_path and not save_path.endswith('/'):
             raise ValueError("save_path must end with a '/'")
         
-        return os.path.join(os.getcwd(), filename)
+        return os.getcwd()
     
     
-    def _get_file_ext(self, response: requests.Response) -> str:
+    def _get_file_name(self, response: requests.Response) -> str:
         """
-        Get the file extension of the response.
+        Get the file name from the response.
 
         Args:
             response (requests.Response): The response of the request.
 
         Returns:
-            str: The file extension of the response.
+            str: The file name 
         """
-        ext = ""
         if 'Content-Disposition' in response.headers and 'filename=' in response.headers['Content-Disposition']:
-            content_disposition = response.headers['Content-Disposition']
-            filename = content_disposition.split('filename=')[-1].strip().strip('"')
-            ext = f".{filename.split('.')[-1]}"
+            file_name = response.headers['Content-Disposition'].split('filename=')[-1].strip().strip('"')
 
         else:
             content_type = response.headers.get("Content-Type", "")
-            ext = mimetypes.guess_extension(content_type.split(";")[0])
+            file_name = f'{self.name}.{mimetypes.guess_extension(content_type.split(";")[0])}'
 
-        return ext
+        return file_name
 
 
-    def download(self, save_path: str = None) -> str:
+    def _create_progress_bar(self) -> 'tqdm':
+        """Creates a progress bar for the task."""
+        try:
+            from tqdm.auto import tqdm
+        except ImportError:
+            from .api import logger
+            logger.warning("[tqdm] extra is required to show the progress bar. install with: pip insatll geobox[tqdm]")
+            return None
+
+        return tqdm(unit="B", 
+                        total=int(self.size), 
+                        file=sys.stdout,
+                        dynamic_ncols=True,
+                        desc="Downloading",
+                        unit_scale=True,
+                        unit_divisor=1024, 
+                        ascii=True
+                )
+
+
+    def download(self, save_path: str = None, progress_bar: bool = True) -> str:
         """
         Download the raster.
 
         Args:
-            save_path (str): The path to save the raster.
-
+            save_path (str, optional): Path where the file should be saved. 
+                                    If not provided, it saves to the current working directory
+                                    using the original filename and appropriate extension.
+            progress_bar (bool, optional): Whether to show a progress bar. default: True
+        
         Returns:
             str: The path to save the raster.
 
@@ -390,23 +411,32 @@ class Raster(Base):
         save_path = self._get_save_path(save_path)
         os.makedirs(os.path.dirname(save_path), exist_ok=True)
         
-        with self.api.get(f"{self.endpoint}download/", stream=True) as response, \
-            open(save_path, 'wb') as f:
-            for chunk in response.iter_content(chunk_size=8192):
-                f.write(chunk)
+        with self.api.get(f"{self.endpoint}download/", stream=True) as response:
+            file_name = self._get_file_name(response)
+            full_path = f"{save_path}/{file_name}"
+            with open(full_path, 'wb') as f:
+                pbar = self._create_progress_bar() if progress_bar else None
+                for chunk in response.iter_content(chunk_size=8192):
+                    f.write(chunk)
+                    if pbar:
+                        pbar.update(len(chunk))
+                        pbar.refresh()
+                if pbar:
+                    pbar.close()
 
-        final_path = os.path.abspath(save_path) + self._get_file_ext(response)
-        os.rename(os.path.abspath(save_path), os.path.abspath(final_path))
-        return os.path.abspath(final_path)
+        return os.path.abspath(full_path)
 
 
-    def get_content_file(self, save_path: str = None) -> str: 
+    def get_content_file(self, save_path: str = None, progress_bar: bool = True) -> str: 
         """
         Get Raster Content URL
 
         Args:
-            save_path (str): The path to save the raster.
-
+            save_path (str, optional): Path where the file should be saved. 
+                                    If not provided, it saves to the current working directory
+                                    using the original filename and appropriate extension.
+            progress_bar (bool, optional): Whether to show a progress bar. default: True
+        
         Returns:
             str: The path to save the raster.
 
@@ -427,17 +457,23 @@ class Raster(Base):
         save_path = self._get_save_path(save_path)
         os.makedirs(os.path.dirname(save_path), exist_ok=True)
         
-        with self.api.get(f"{self.endpoint}content/", stream=True) as response, \
-            open(save_path, 'wb') as f:
-            for chunk in response.iter_content(chunk_size=8192):
-                f.write(chunk)
+        with self.api.get(f"{self.endpoint}content/", stream=True) as response:
+            file_name = self._get_file_name(response)
+            full_path = f"{save_path}/{file_name}"
+            with open(full_path, 'wb') as f:
+                pbar = self._create_progress_bar() if progress_bar else None
+                for chunk in response.iter_content(chunk_size=8192):
+                    f.write(chunk)
+                    if pbar:
+                        pbar.update(len(chunk))
+                        pbar.refresh()
+                if pbar:
+                    pbar.close()
 
-        final_path = os.path.abspath(save_path) + self._get_file_ext(response)
-        os.rename(os.path.abspath(save_path), os.path.abspath(final_path))
-        return os.path.abspath(final_path)
+        return os.path.abspath(full_path)
 
 
-    def get_tile_render_url(self, x: int, y: int, z: int) -> str:
+    def get_render_png_url(self, x: int, y: int, z: int, **kwargs) -> str:
         """
         Get the PNG URL of the raster.
 
@@ -446,6 +482,15 @@ class Raster(Base):
             y (int): The y coordinate of the tile.
             z (int): The zoom level of the tile.
 
+        Keyword Args:
+            indexes (str, optional): list of comma separated band indexes to be rendered. e.g. 1, 2, 3
+            nodata (int, optional)
+            expression (str, optional): band math expression. e.g. b1*b2+b3
+            rescale (List, optional): comma (',') separated Min,Max range. Can set multiple time for multiple bands.
+            color_formula (str, optional): Color formula. e.g. gamma R 0.5
+            colormap_name (str, optional)
+            colormap (str, optional): JSON encoded custom Colormap. e.g. {"0": "#ff0000", "1": "#00ff00"} or [[[0, 100], "#ff0000"], [[100, 200], "#00ff00"]]
+
         Returns:
             str: The PNG Render URL of the raster.
 
@@ -456,11 +501,22 @@ class Raster(Base):
             >>> raster = Raster.get_raster(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> raster.get_tile_render_url(x=10, y=20, z=1)
         """
+        params = clean_data({
+            'indexes': kwargs.get('indexes'),
+            'nodata': kwargs.get('nodata'),
+            'expression': kwargs.get('expression'),
+            'rescale': kwargs.get('rescale'),
+            'color_formula': kwargs.get('color_formula'),
+            'colormap_name': kwargs.get('colormap_name'),
+            'colormap': kwargs.get('colormap')
+        })
+        query_string = urlencode(params)
         endpoint = urljoin(self.api.base_url, f'{self.endpoint}render/{z}/{x}/{y}.png')
+        endpoint = urljoin(endpoint, f'?{query_string}')
         return endpoint
     
 
-    def get_tile_pbf_url(self, x: int, y: int, z: int) -> str:
+    def get_tile_pbf_url(self, x: int, y: int, z: int, indexes: str = None) -> str:
         """
         Get the URL of the tile.
 
@@ -468,6 +524,7 @@ class Raster(Base):
             x (int): The x coordinate of the tile.
             y (int): The y coordinate of the tile.
             z (int): The zoom level of the tile.
+            indexes (str, optional): list of comma separated band indexes to be rendered. e.g. 1, 2, 3
 
         Returns:
             str: The URL of the tile.
@@ -479,7 +536,12 @@ class Raster(Base):
             >>> raster = Raster.get_raster(client, uuid="12345678-1234-5678-1234-567812345678")
             >>> raster.get_tile_pbf_url(x=10, y=20, z=1)
         """
+        params = clean_data({
+            'indexes': indexes
+        })
+        query_string = urlencode(params)
         endpoint = urljoin(self.api.base_url, f'{self.endpoint}tiles/{z}/{x}/{y}.pbf')
+        endpoint = urljoin(endpoint, f'?{query_string}')
         return endpoint
     
 
@@ -608,10 +670,7 @@ class Raster(Base):
             'min_zoom', 'max_zoom', 'use_cache', 'cache_until_zoom'
         }
 
-        settings = {
-            'visual_settings': {},
-            'tile_settings': {}
-        }
+        settings = self.settings
 
         for key, value in kwargs.items():
             if key in visual_settings:
@@ -620,7 +679,7 @@ class Raster(Base):
                 settings['tile_settings'][key] = value
 
 
-        super()._set_settings(self.endpoint, settings)
+        return super()._set_settings(self.endpoint, settings)
 
 
     def share(self, users: List['User']) -> None:
