@@ -3,8 +3,8 @@ from typing import Dict, List, Optional, Union, TYPE_CHECKING
 
 from .base import Base
 from .vectorlayer import VectorLayer
+from .view import VectorLayerView
 from .task import Task
-from .enums import TilesetLayerType
 
 if TYPE_CHECKING:
     from . import GeoboxClient 
@@ -35,7 +35,7 @@ class Tileset(Base):
 
 
     @classmethod
-    def create_tileset(cls, api: 'GeoboxClient', name: str, layers: List[Dict], display_name: str = None, description: str = None,
+    def create_tileset(cls, api: 'GeoboxClient', name: str, layers: List[Union['VectorLayer', 'VectorLayerView']], display_name: str = None, description: str = None,
                         min_zoom: int = None, max_zoom: int = None, user_id: int = None) -> 'Tileset':
         """
         Create a new tileset.
@@ -43,9 +43,7 @@ class Tileset(Base):
         Args:
             api (GeoboxClient): The GeoboxClient instance for making requests.
             name (str): The name of the tileset.
-            layers (List[Dict]): The layers of the tileset. a list of dictionaries with the following keys:
-                - layer_type: The type of the layer. valid values are "vector" and "view".
-                - layer_uuid: The uuid of the layer.
+            layers (List['VectorLayer' | 'VectorLayerView']): list of vectorlayer and view objects to add to tileset.
             display_name (str, optional): The display name of the tileset.
             description (str, optional): The description of the tileset.
             min_zoom (int, optional): The minimum zoom level of the tileset.
@@ -59,34 +57,46 @@ class Tileset(Base):
             >>> from geobox import GeoboxClient
             >>> from geobox.tileset import Tileset
             >>> client = GeoboxClient()
-            >>> layers = [
-            ...     {
-            ...     "layer_type": "vector",
-            ...     "layer_uuid": "12345678-1234-5678-1234-567812345678"
-            ...     }
-            ... ]
+            >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> view = client.get_view(uuid="12345678-1234-5678-1234-567812345678")
             >>> tileset = Tileset.create_tileset(client, 
             ...                                     name="your_tileset_name", 
             ...                                     display_name="Your Tileset", 
             ...                                     description="Your description", 
             ...                                     min_zoom=0, 
             ...                                     max_zoom=14, 
-            ...                                     layers=layers)
+            ...                                     layers=[layer, view])
             or 
             >>> tileset = client.create_tileset(name="your_tileset_name", 
             ...                                     display_name="Your Tileset", 
             ...                                     description="Your description", 
             ...                                     min_zoom=0, 
             ...                                     max_zoom=14, 
-            ...                                     layers=layers)
+            ...                                     layers=[layer, view])
         """
+        formatted_layers = []
+        for item in layers:
+            if type(item) == VectorLayer:
+                item_type = 'vector'
+
+            elif type(item) == VectorLayerView:
+                item_type = 'view'
+
+            else:
+                continue
+
+            formatted_layers.append({
+                'layer_type': item_type,
+                'layer_uuid': item.uuid
+            })
+
         data = {
             "name": name,
             "display_name": display_name,
             "description": description,
             "min_zoom": min_zoom,
             "max_zoom": max_zoom,
-            "layers": layers,
+            "layers": formatted_layers,
             "user_id": user_id
         }
         return super()._create(api, cls.BASE_ENDPOINT, data, factory_func=lambda api, item: Tileset(api, item['uuid'], item))
@@ -283,7 +293,7 @@ class Tileset(Base):
         super().delete(urljoin(self.BASE_ENDPOINT, f'{self.uuid}/'))
     
     
-    def get_tileset_layers(self, **kwargs) -> List['VectorLayer']:
+    def get_layers(self, **kwargs) -> List['VectorLayer']:
         """
         Retrieves the layers of the tileset with optional parameters.
 
@@ -307,13 +317,14 @@ class Tileset(Base):
         Example:
 
         Returns:
-            List: A list of VectorLayer instances.
+            List: A list of VectorLayer or VectorLayerView instances.
 
         Example:
             >>> from geobox import GeoboxClient
             >>> from geobox.tileset import Tileset
             >>> client = GeoboxClient()
-            >>> tilesets = Tileset.get_tileset_layers()
+            >>> tileset = Tileset.get_tileset(client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> layers = tileset.get_layers()
         """
         params = {
             'f': 'json',
@@ -328,57 +339,82 @@ class Tileset(Base):
             'shared': kwargs.get('shared', False)
         }
         endpoint = urljoin(self.BASE_ENDPOINT, f'{self.uuid}/layers/')
-        return super()._get_list(self.api, endpoint, params, factory_func=lambda api, item: VectorLayer(api, item['uuid'], item['layer_type'], item))
+        return super()._get_list(self.api, endpoint, params, factory_func=lambda api, item: VectorLayer(api, item['uuid'], item['layer_type'], item) if not item['is_view'] else \
+                                                                                            VectorLayerView(api, item['uuid'], item['layer_type'], item)                                    )
 
 
-    def add_layer(self, layer_type: TilesetLayerType, layer_uuid: str) -> None:
+    def add_layer(self, layer: Union['VectorLayer', 'VectorLayerView']) -> None:
         """
         Adds a layer to the tileset.
 
         Args:
-            layer_type (TilesetLayerType): The type of the layer. "vector" or "view".
-            layer_uuid (str): The UUID of the layer.
+            layer (VectorLayer | VectorLayerView): the layer object to add to the tileset
 
         Returns:
             None
 
+        Raises:
+            ValueError: if the layer input is not a 'VectorLayer' or 'VetorLayerview' object
+
         Example:
             >>> from geobox import GeoboxClient
             >>> from geobox.tileset import Tileset
             >>> client = GeoboxClient()
             >>> tileset = Tileset.get_tileset(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> tileset.add_layer_tileset(layer_type=TilesetLayerType.Vector, layer_uuid="12345678-1234-5678-1234-567812345678")
+            >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> tileset.add_layer(layer)
         """
+        if type(layer) == VectorLayer:
+            layer_type = 'vector'
+
+        elif type(layer) == VectorLayerView:
+            layer_type = 'view'
+
+        else:
+            raise ValueError("layer input must be either 'VectorLayer' or 'VetorLayerview' object")
+
         data = {
-            "layer_type": layer_type.value,
-            "layer_uuid": layer_uuid
+            "layer_type": layer_type,
+            "layer_uuid": layer.uuid
         }
 
         endpoint = urljoin(self.endpoint, 'layers/')
         return self.api.post(endpoint, data, is_json=False)
 
 
-    def delete_layer(self, layer_type: TilesetLayerType, layer_uuid: str) -> None:
+    def delete_layer(self, layer: Union['VectorLayer', 'VectorLayerView']) -> None:
         """
         Deletes a layer from the tileset.
 
         Args:
-            layer_type (TilesetLayerType): The type of the layer. "vector" or "view".
-            layer_uuid (str): The UUID of the layer.
+            layer (VectorLayer | VectorLayerView): the layer object to delete from the tileset
 
         Returns:
             None
 
+        Raises:
+            ValueError: if the layer input is not a 'VectorLayer' or 'VetorLayerview' object
+
         Example:
             >>> from geobox import GeoboxClient
             >>> from geobox.tileset import Tileset
             >>> client = GeoboxClient()
             >>> tileset = Tileset.get_tileset(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> tileset.delete_layer_tileset(layer_type=TilesetLayerType.Vector, layer_uuid="12345678-1234-5678-1234-567812345678")
+            >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> tileset.delete_layer(layer)
         """
+        if type(layer) == VectorLayer:
+            layer_type = 'vector'
+
+        elif type(layer) == VectorLayerView:
+            layer_type = 'view'
+
+        else:
+            raise ValueError("layer input must be either 'VectorLayer' or 'VetorLayerview' object")
+
         data = {
-            "layer_type": layer_type.value,
-            "layer_uuid": layer_uuid
+            "layer_type": layer_type,
+            "layer_uuid": layer.uuid
         }
 
         endpoint = urljoin(self.endpoint, 'layers/')
