@@ -1,4 +1,11 @@
 from urllib.parse import urlparse, parse_qs, urlencode, urlunparse
+import base64
+
+
+def xor_encode(s, key=42):
+    xor_str = ''.join(chr(ord(c) ^ key) for c in s)
+    encoded_bytes = base64.b64encode(xor_str.encode('utf-8'))
+    return encoded_bytes.decode('utf-8')
 
 
 def clean_data(data: dict) -> dict:
