@@ -16,6 +16,7 @@ if TYPE_CHECKING:
     from .api import GeoboxClient
     from .view import VectorLayerView
     from .user import User
+    from .file import File
 
 class VectorLayer(Base):
     """
@@ -226,6 +227,7 @@ class VectorLayer(Base):
                      display_name: str = None,
                      description: str = None, 
                      has_z: bool = False, 
+                     temporary: bool = False,
                      fields: List = None) -> 'VectorLayer':
         """
         Create a new vector layer.
@@ -237,6 +239,7 @@ class VectorLayer(Base):
             display_name (str, optional): A human-readable name for the layer. default is None.
             description (str, optional): A description of the layer. default is None.
             has_z (bool, optional): Whether the layer includes Z coordinates. default is False.
+            temporary (bool, optional): Whether to create a temporary layer. temporary layers will be deleted after 24 hours. default is False.
             fields (List, optional): List of field definitions for the layer. default is None.
             
         Returns:
@@ -255,6 +258,7 @@ class VectorLayer(Base):
             ...                                 display_name="My Layer",
             ...                                 description="This is a description of my layer",
             ...                                 has_z=False,
+            ...                                 temporary=True,
             ...                                 fields=[{"name": "my_field", "datatype": "FieldTypeString"}])
             or
             >>> layer = client.create_vector(name="my_layer", 
@@ -262,6 +266,7 @@ class VectorLayer(Base):
             ...                                 display_name="My Layer",
             ...                                 description="This is a description of my layer",
             ...                                 has_z=False,
+            ...                                 temporary=True,
             ...                                 fields=[{"name": "my_field", "datatype": "FieldTypeString"}])
         """
         data = {
@@ -270,6 +275,7 @@ class VectorLayer(Base):
             "display_name": display_name,
             "description": description,
             "has_z": has_z,
+            "temporary": temporary,
             "fields": fields
         }
         return super()._create(api=api, 
@@ -332,7 +338,8 @@ class VectorLayer(Base):
         Make the layer permanent.
         """
         endpoint = urljoin(self.endpoint, 'makePermanent/')
-        self.api.post(endpoint, is_json=False)
+        response = self.api.post(endpoint, is_json=False)
+        self._update_properties(response)
 
 
     def share(self, users: List['User']) -> None:
@@ -432,6 +439,36 @@ class VectorLayer(Base):
         return super()._create(self.api, endpoint, data, factory_func=lambda api, item: VectorLayerVersion(api, item['uuid'], item))
 
 
+    def get_versions(self, **kwargs) -> List['VectorLayerVersion']:
+        """
+        Get list of versions of the current vector layer object with optional filtering and pagination.
+
+        Keyword Args:
+            q (str): query filter based on OGC CQL standard. e.g. "field1 LIKE '%GIS%' AND created_at > '2021-01-01'"
+            search (str): search term for keyword-based searching among search_fields or all textual fields if search_fields does not have value. NOTE: if q param is defined this param will be ignored.
+            search_fields (str): comma separated list of fields for searching.
+            order_by (str): comma separated list of fields for sorting results [field1 A|D, field2 A|D, …]. e.g. name A, type D. NOTE: "A" denotes ascending order and "D" denotes descending order.
+            return_count (bool): Whether to return total count. default is False.
+            skip (int): Number of items to skip. default is 0.
+            limit (int): Number of items to return. default is 10.
+            user_id (int): Specific user. privileges required.
+            shared (bool): Whether to return shared versions. default is False.
+
+        Returns:
+            List[VectorLayerVersion] | int: A list of vector layer version instances or the total number of versions.
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.version import VectorLayerVersion
+            >>> client = GeoboxClient()
+            >>> layer = client.get_vector(uuid="12345678-1234-5678-1234-567812345678")
+            >>> versions = layer.get_versions()
+            or
+            >>> versions = layer.get_versions()
+        """
+        return VectorLayerVersion.get_versions(self.api, layer_id=self.id, **kwargs)
+
+
     @property    
     def wfs(self) -> str:
         """
@@ -447,7 +484,10 @@ class VectorLayer(Base):
             >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
             >>> layer.wfs
         """
-        return f'{self.api.base_url}{self.endpoint}wfs/'
+        if self.api.access_token:
+            return f'{self.api.base_url}{self.endpoint}wfs/'
+        elif self.api.apikey:
+            return f'{self.api.base_url}{self.endpoint}apikey:{self.api.apikey}/wfs/'
 
 
     def get_fields(self) -> List['Field']:
@@ -470,41 +510,56 @@ class VectorLayer(Base):
                             factory_func=lambda api, item: Field(layer=self, data_type=FieldType(item['datatype']), field_id=item['id'], data=item))
 
 
-    def get_field(self, field_id: str = None, name: str = None) -> 'Field':
+    def get_field(self, field_id: int) -> 'Field':
         """
         Get a specific field by its ID.
         
         Args:
-            field_id (str, optional): The ID of the field to retrieve.
-            name (str, optional): The name of the field to retrieve.
+            field_id (int, optional): The ID of the field to retrieve.
 
         Returns:
             Field: The requested field instance.
             
         Raises:
-            ValueError: Either id or name must be provided.
-            NotFoundError: If the field with the specified ID or name is not found. 
+            NotFoundError: If the field with the specified ID is not found. 
 
         Example:
             >>> from geobox import GeoboxClient
             >>> from geobox.vectorlayer import VectorLayer
             >>> client = GeoboxClient()
             >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> field = layer.get_field(field_id="1")
-        """
-        if not (field_id or name):
-            raise ValueError('Either "field_id" or "name" must be provided')
-        
-        if field_id:
-            field = next((f for f in self.get_fields() if str(f.id) == str(field_id)), None)
-        elif name:
-            field = next((f for f in self.get_fields() if f.name == name), None)
-
+            >>> field = layer.get_field(field_id=1)
+        """        
+        field = next((f for f in self.get_fields() if f.id == field_id), None)
         if not field:
-            if field_id:
-                raise NotFoundError(f'Field with ID {field_id} not found in layer {self.name}')
-            elif name:
-                raise NotFoundError(f'Field with name "{name}" not found in layer {self.name}')
+            raise NotFoundError(f'Field with ID {field_id} not found in layer {self.name}')
+            
+        return field
+
+
+    def get_field_by_name(self, name: str) -> 'Field':
+        """
+        Get a specific field by its name.
+        
+        Args:
+            name (str, optional): The name of the field to retrieve.
+
+        Returns:
+            Field: The requested field instance.
+            
+        Raises:
+            NotFoundError: If the field with the specified name is not found. 
+
+        Example:
+            >>> from geobox import GeoboxClient
+            >>> from geobox.vectorlayer import VectorLayer
+            >>> client = GeoboxClient()
+            >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
+            >>> field = layer.get_field_by_name(name='test')
+        """        
+        field = next((f for f in self.get_fields() if f.name == name), None)
+        if not field:
+            raise NotFoundError(f"Field with name '{name}' not found in layer {self.name}")
             
         return field
 
@@ -542,7 +597,7 @@ class VectorLayer(Base):
                         bbox_srid: int = None, 
                         feature_ids: List = None, 
                         run_async: bool = True, 
-                        user_id: int = None) -> 'Task':
+                        user_id: int = None) -> Union['Task', Dict]:
         """
         Calculate values for a field based on an expression.
         
@@ -557,7 +612,7 @@ class VectorLayer(Base):
             user_id (int, optional): Specific user. privileges required.
             
         Returns:
-            Task: The task instance of the calculation operation.
+            Task | Dict: The task instance of the calculation operation or the api response if the run_async=False.
 
         Example:
             >>> from geobox import GeoboxClient
@@ -585,8 +640,11 @@ class VectorLayer(Base):
         
         endpoint = urljoin(self.endpoint, 'calculateField/')
         response = self.api.post(endpoint, data, is_json=False)
-        task = Task.get_task(self.api, response.get('task_uuid'))
-        return task
+        if run_async:
+            task = Task.get_task(self.api, response.get('task_id'))
+            return task
+
+        return response
 
 
     def get_features(self, **kwargs) -> Union[List['Feature'], int]:
@@ -713,21 +771,21 @@ class VectorLayer(Base):
         return Feature.create_feature(self, geojson)
 
 
-    def delete_features(self, q: str = None, bbox: List[float] = None, bbox_srid: int = None, feature_ids: List[int] = None, 
-                        run_async: bool = True, user_id: int = None) -> 'Task':
+    def delete_features(self, q: str = None, bbox: str = None, bbox_srid: int = None, feature_ids: List[int] = None, 
+                        run_async: bool = True, user_id: int = None) -> Union['Task', Dict]:
         """
         Delete features from the layer based on specified criteria.
         
         Args:
-            q (Optional[str]): Query to filter features to delete.
-            bbox (Optional[List[float]]): Bounding box to filter features.
-            bbox_srid (Optional[int]): Spatial reference ID for the bounding box.
-            feature_ids (Optional[List[int]]): List of specific feature IDs to delete.
-            run_async (Optional[bool]): Whether to run the deletion asynchronously. default is True.
-            user_id (Optional[int]): Specific user. privileges required.
+            q (str, optional): Query to filter features to delete.
+            bbox (str, optional): Comma seprated bbox.
+            bbox_srid (int, optional): Spatial reference ID for the bounding box.
+            feature_ids (str, optional): Comma seprated feature ids.
+            run_async (bool, optional): Whether to run the deletion asynchronously. default is True.
+            user_id (int, optional): Specific user. privileges required.
             
         Returns:
-            Task: The task instance of the deletion operation.
+            Task | Dict: The task instance of the deletion operation or the api response if run_async=False.
             
         Raises:
             ValidationError: If the deletion parameters are invalid.
@@ -738,9 +796,9 @@ class VectorLayer(Base):
             >>> client = GeoboxClient()
             >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
             >>> layer.delete_features(q="name like 'my_layer'", 
-            ...                         bbox=[10, 20, 30, 40],
+            ...                         bbox='10, 20, 30, 40',
             ...                         bbox_srid=3857, 
-            ...                         feature_ids=[1, 2, 3], 
+            ...                         feature_ids='1, 2, 3', 
             ...                         run_async=True)
         """
         data = clean_data({
@@ -754,19 +812,29 @@ class VectorLayer(Base):
 
         endpoint = urljoin(self.endpoint, 'deleteFeatures/')
         response = self.api.post(endpoint, data, is_json=False)
-        task = Task.get_task(self.api, response.get('task_id'))
-        return task
+        if run_async:
+            task = Task.get_task(self.api, response.get('task_id'))
+            return task
+
+        return response
 
 
-    def import_features(self, file_uuid: str, input_geom_type: 'InputGeomType', input_layer_name: str = None, input_dataset: str = None, 
-                        user_id: int = None, input_srid: int = None, file_encoding: str = "utf-8", 
-                        replace_domain_codes_by_values: bool = False, report_errors: bool = True) -> 'Task':
+    def import_features(self, 
+                            file: 'File', 
+                            input_geom_type: 'InputGeomType' = None, 
+                            input_layer_name: str = None, 
+                            input_dataset: str = None, 
+                            user_id: int = None, 
+                            input_srid: int = None, 
+                            file_encoding: str = "utf-8", 
+                            replace_domain_codes_by_values: bool = False, 
+                            report_errors: bool = True) -> 'Task':
         """
         Import features from a file into the layer.
         
         Args:
-            file_uuid (str): UUID of the uploaded file to import.
-            input_geom_type (InputGeomType): Type of geometry in the input file.
+            file (File): file object to import.
+            input_geom_type (InputGeomType, optional): Type of geometry in the input file.
             input_layer_name (str, optional): Name of the layer in the input file.
             input_dataset (str, optional): Name of the dataset in the input file.
             user_id (int, optional): Specific user. privileges required.
@@ -786,7 +854,8 @@ class VectorLayer(Base):
             >>> from geobox.vectorlayer import VectorLayer
             >>> client = GeoboxClient()
             >>> layer = VectorLayer.get_vector(api=client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> task = layer.import_features(file_uuid="12345678-1234-5678-1234-567812345678", 
+            >>> file = client.get_file(uuid="12345678-1234-5678-1234-567812345678")
+            >>> task = layer.import_features(file=file, 
             ...                         input_geom_type=InputGeomType.POINT,
             ...                         input_layer_name="my_layer",
             ...                         input_dataset="my_dataset",
@@ -796,7 +865,7 @@ class VectorLayer(Base):
             ...                         report_errors=True)
         """
         data = clean_data({
-            "file_uuid": file_uuid,
+            "file_uuid": file.uuid,
             "input_layer": input_layer_name,
             "input_geom_type": input_geom_type.value if isinstance(input_geom_type, InputGeomType) else input_geom_type,
             "replace_domain_codes_by_values": replace_domain_codes_by_values,
@@ -813,9 +882,17 @@ class VectorLayer(Base):
         return task
 
 
-    def export_features(self, out_filename: str, out_format: 'FileOutputFormat', replace_domain_codes_by_values: bool = False, 
-                        run_async: bool = True, bbox: List[float] = None, out_srid: int = None, zipped: bool = True, 
-                        feature_ids: List[int] = None, bbox_srid: int = None, q: str = None, fields: List[str] = None) -> 'Task':
+    def export_features(self, 
+                            out_filename: str, 
+                            out_format: 'FileOutputFormat', 
+                            replace_domain_codes_by_values: bool = False, 
+                            run_async: bool = True, 
+                            bbox: List[float] = None, 
+                            out_srid: int = None, 
+                            zipped: bool = True, 
+                            feature_ids: List[int] = None, 
+                            bbox_srid: int = None, 
+                            q: str = None, fields: List[str] = None) -> Union['Task', Dict]:
         """
         Export features from the layer to a file.
         
@@ -833,7 +910,7 @@ class VectorLayer(Base):
             fields (List[str], optional): List of fields to include in the export.
             
         Returns:
-            Task: The task instance of the export operation.
+            Task | Dict: The task instance of the export operation or the api response if run_async=False.
             
         Raises:
             ValidationError: If the export parameters are invalid.
@@ -868,8 +945,11 @@ class VectorLayer(Base):
 
         endpoint = urljoin(self.endpoint, 'export/')
         response = self.api.post(endpoint, data, is_json=False)
-        task = Task.get_task(self.api, response.get('task_id'))
-        return task
+        if run_async:
+            task = Task.get_task(self.api, response.get('task_id'))
+            return task
+
+        return response
 
 
     def create_view(self, name: str, display_name: str = None, description: str = None, 
@@ -1031,11 +1111,7 @@ class VectorLayer(Base):
         edit_settings = {'editable', 'edit_geometry', 'editable_attributes', 'allow_insert', 'allow_delete'}
         tile_settings = {'min_zoom', 'max_zoom', 'max_features', 'filter_features', 'fields', 'use_cache', 'cache_until_zoom'}
 
-        settings = {
-            'general_settings': {},
-            'edit_settings': {},
-            'tile_settings': {}
-        }
+        settings = self.settings
 
         for key, value in kwargs.items():
             if key in general_settings:
