@@ -9,6 +9,7 @@ if TYPE_CHECKING:
     from .user import User
     from .enums import InputGeomType, FieldType
     from .task import Task
+    from .file import File
 
 
 class VectorLayerView(VectorLayer):
@@ -163,7 +164,7 @@ class VectorLayerView(VectorLayer):
             'include_settings': include_settings
         }
         return super()._get_list_by_ids(api=api, 
-                                        endpoint=f'{cls.BASE_ENDPOINT}get-views/', 
+                                        endpoint=f'{cls.BASE_ENDPOINT}get-layers/', 
                                         params=params, 
                                         factory_func=lambda api, item: VectorLayerView(api, item['uuid'], LayerType(item['layer_type']), item))
 
@@ -201,7 +202,7 @@ class VectorLayerView(VectorLayer):
 
 
     @classmethod
-    def get_view_by_name(cls, api: 'GeoboxClient', name: str, user_id: int = None) -> Union['View', None]:
+    def get_view_by_name(cls, api: 'GeoboxClient', name: str, user_id: int = None) -> Union['VectorLayerView', None]:
         """
         Get a view by name
 
@@ -211,7 +212,7 @@ class VectorLayerView(VectorLayer):
             user_id (int, optional): specific user. privileges required.
 
         Returns:
-            View | None: returns the view if a view matches the given name, else None
+            VectorLayerView | None: returns the view if a view matches the given name, else None
 
         Example:
             >>> from geobox import GeoboxClient
@@ -361,13 +362,12 @@ class VectorLayerView(VectorLayer):
         return super().get_fields()
     
 
-    def get_field(self, field_id: str = None, name: str = None) -> 'Field':
+    def get_field(self, field_id: int) -> 'Field':
         """
         Get a specific field by its ID or name.
         
         Args:
-            field_id (str): The ID of the field to retrieve.
-            name (str): The name of the field to retrieve.
+            field_id (int): The ID of the field to retrieve.
 
         Returns:
             Field: The requested field instance.
@@ -381,40 +381,37 @@ class VectorLayerView(VectorLayer):
             >>> from geobox.view import VectorLayerView
             >>> client = GeoboxClient()
             >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> field = view.get_field(id="1")
+            >>> field = view.get_field(id=1)
         """
-        return super().get_field(field_id, name)
+        return super().get_field(field_id)
 
 
-    def add_field(self, name: str, data_type: 'FieldType', data: Dict = {}) -> 'Field':
+    def get_field_by_name(self, name: str) -> 'Field':
         """
-        Add a new field to the vector layer view.
+        Get a specific field by its name.
         
         Args:
-            name (str): The name of the new field.
-            data_type (FieldType): The data type of the new field.
-            data (Dict): Additional field properties (display_name, description, etc.).
-            
+            name (str, optional): The name of the field to retrieve.
+
         Returns:
-            Field: The newly created field instance.
+            Field: The requested field instance.
             
         Raises:
-            ValidationError: If the field data is invalid.
-            ApiRequestError: If the API request fails.
+            NotFoundError: If the field with the specified name is not found. 
 
         Example:
             >>> from geobox import GeoboxClient
             >>> from geobox.view import VectorLayerView
             >>> client = GeoboxClient()
             >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> field = view.add_field(name="new_field", data_type=FieldType.String)
-        """
-        return  super().add_field(name, data_type, data)
+            >>> field = view.get_field_by_name(name='test')
+        """      
+        return super().get_field_by_name(name)
     
 
     def calculate_field(self, target_field: str, expression: str, q: str = None, bbox: List[float] = None, 
                         bbox_srid: int = None, feature_ids: List = None, run_async: bool = True, 
-                        user_id: int = None) -> 'Task':
+                        user_id: int = None) -> Union['Task', Dict]:
         """
         Calculate values for a field based on an expression.
         
@@ -429,7 +426,7 @@ class VectorLayerView(VectorLayer):
             user_id (Optional[int]): ID of the user running the calculation.
             
         Returns:
-            Task: The task instance of the calculation operation.
+            Task | Dict: The task instance of the calculation operation or the api response if the run_async=False.
             
         Raises:
             ValidationError: If the calculation parameters are invalid.
@@ -541,7 +538,7 @@ class VectorLayerView(VectorLayer):
 
 
     def delete_features(self, q: str = None, bbox: List[float] = None, bbox_srid: int = None, feature_ids: List[int] = None, 
-                        run_async: bool = True, user_id: int = None) -> 'Task':
+                        run_async: bool = True, user_id: int = None) -> Union['Task', Dict]:
         """
         Delete features from the layer based on specified criteria.
         
@@ -554,7 +551,7 @@ class VectorLayerView(VectorLayer):
             user_id (Optional[int]): ID of the user performing the deletion.
             
         Returns:
-            Task: The task instance of the deletion operation.
+            Task | Dict: The task instance of the deletion operation or the api response if run_async=False.
             
         Raises:
             ValidationError: If the deletion parameters are invalid.
@@ -573,15 +570,22 @@ class VectorLayerView(VectorLayer):
         return super().delete_features(q, bbox, bbox_srid, feature_ids, run_async, user_id)
 
 
-    def import_features(self, file_uuid: str, input_geom_type: 'InputGeomType', input_layer_name: str = None, input_dataset: str = None, 
-                        user_id: int = None, input_srid: int = None, file_encoding: str = "utf-8", 
-                        replace_domain_codes_by_values: bool = False, report_errors: bool = True) -> 'Task':
+    def import_features(self,
+                            file: 'File', 
+                            input_geom_type: 'InputGeomType' = None, 
+                            input_layer_name: str = None, 
+                            input_dataset: str = None, 
+                            user_id: int = None, 
+                            input_srid: int = None, 
+                            file_encoding: str = "utf-8", 
+                            replace_domain_codes_by_values: bool = False, 
+                            report_errors: bool = True) -> 'Task':
         """
         Import features from a file into the layer.
         
         Args:
-            file_uuid (str): UUID of the uploaded file to import.
-            input_geom_type (InputGeomType): Type of geometry in the input file.
+            file (File): file object to import.
+            input_geom_type (InputGeomType, optional): Type of geometry in the input file.
             input_layer_name (str, optional): Name of the layer in the input file.
             input_dataset (str, optional): Name of the dataset in the input file.
             user_id (int, optional): Specific user.privileges requied.
@@ -601,7 +605,8 @@ class VectorLayerView(VectorLayer):
             >>> from geobox.view import VectorLayerView
             >>> client = GeoboxClient()
             >>> view = VectorLayerView.get_view(client, uuid="12345678-1234-5678-1234-567812345678")
-            >>> task = view.import_features(file_uuid="12345678-1234-5678-1234-567812345678", 
+            >>> file = client.get_file(uuid="12345678-1234-5678-1234-567812345678")
+            >>> task = view.import_features(file=file, 
             ...                         input_geom_type=InputGeomType.POINT,
             ...                         input_layer="my_layer",
             ...                         input_dataset="my_dataset",
@@ -610,13 +615,13 @@ class VectorLayerView(VectorLayer):
             ...                         replace_domain_codes_by_values=False, 
             ...                         report_errors=True)
         """
-        return super().import_features(file_uuid, input_geom_type, input_layer_name, input_dataset, user_id, 
+        return super().import_features(file, input_geom_type, input_layer_name, input_dataset, user_id, 
                                        input_srid, file_encoding, replace_domain_codes_by_values, report_errors)
 
 
     def export_features(self, out_filename: str, out_format: 'FileOutputFormat', replace_domain_codes_by_values: bool = False, 
                         run_async: bool = True, bbox: List[float] = None, out_srid: int = None, zipped: bool = True, 
-                        feature_ids: List[int] = None, bbox_srid: int = None, q: str = None, fields: List[str] = None) -> 'Task':
+                        feature_ids: List[int] = None, bbox_srid: int = None, q: str = None, fields: List[str] = None) -> Union['Task', Dict]:
         """
         Export features from the layer to a file.
         
@@ -634,7 +639,7 @@ class VectorLayerView(VectorLayer):
             fields (List[str], optional): List of fields to include in the export.
             
         Returns:
-            Task: The task instance of the export operation.
+            Task | Dict: The task instance of the export operation or the api response if run_async=False.
             
         Raises:
             ValidationError: If the export parameters are invalid.
