@@ -9,12 +9,12 @@ from geobox.feature import Feature, FeatureType
 from geobox.vectorlayer import VectorLayer, LayerType
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_init(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_init(api, mock_vector_data, mock_feature_data, feature_type):
     """Test initialization of Feature object for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
-    feature = Feature(layer, srid=3857, data=mock_feature_data[geom_type])
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
+    feature = Feature(layer, srid=3857, data=mock_feature_data[feature_type])
     assert feature.layer == layer
     assert feature.id == feature_data['id']
     assert feature.data == feature_data
@@ -22,21 +22,21 @@ def test_init(api, mock_vector_data, mock_feature_data, geom_type):
     assert feature.endpoint == f'{layer.endpoint}features/{feature_data["id"]}/'
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_repr(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_repr(api, mock_vector_data, mock_feature_data, feature_type):
     """Test the repr method of Feature object for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
-    feature = Feature(layer, srid=3857, data=mock_feature_data[geom_type])
-    assert repr(feature) == f"Feature(id={mock_feature_data[geom_type]['id']}, type={FeatureType(geom_type)})"
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
+    feature = Feature(layer, srid=3857, data=mock_feature_data[feature_type])
+    assert repr(feature) == f"Feature(id={mock_feature_data[feature_type]['id']}, type={FeatureType(feature_type)})"
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_dir(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_dir(api, mock_vector_data, mock_feature_data, feature_type):
     """Test the dir method of Feature object for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
-    feature = Feature(layer, srid=3857, data=mock_feature_data[geom_type])
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
+    feature = Feature(layer, srid=3857, data=mock_feature_data[feature_type])
     expected_attrs = list(feature_data.keys()) + list(feature_data['geometry'].keys()) + list(feature_data['properties'].keys())
     actual_attrs = dir(feature)
     # Check that all expected attributes are in the actual dir() result
@@ -44,27 +44,27 @@ def test_dir(api, mock_vector_data, mock_feature_data, geom_type):
         assert attr in actual_attrs, f"Expected attribute '{attr}' not found in dir(feature)"
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_getattr(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_getattr(api, mock_vector_data, mock_feature_data, feature_type):
     """Test the getattr method of Feature object for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
-    feature = Feature(layer, srid=3857, data=mock_feature_data[geom_type])
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
+    feature = Feature(layer, srid=3857, data=mock_feature_data[feature_type])
     assert feature.id == feature_data['id']
     assert feature.name == feature_data['properties']['name']
     assert feature.coordinates == feature_data['geometry']['coordinates']
     assert feature.srid == 3857
-    assert feature.feature_type == FeatureType(geom_type)
+    assert feature.feature_type == FeatureType(feature_type)
     assert feature.geometry == shape(feature_data['geometry'])
     with pytest.raises(AttributeError):
         feature.invalid_property
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_save(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_save(api, mock_vector_data, mock_feature_data, feature_type):
     """Test saving a feature for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     
     request_data = feature_data.copy()
     
@@ -89,11 +89,11 @@ def test_save(api, mock_vector_data, mock_feature_data, geom_type):
     assert feature.data == feature_data
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_save_srid(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_save_srid(api, mock_vector_data, mock_feature_data, feature_type):
     """Test saving a feature with a different srid"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     feature.transform(4326)
     coords = feature.coordinates
@@ -108,21 +108,21 @@ def test_save_srid(api, mock_vector_data, mock_feature_data, geom_type):
     assert feature.coordinates == coords
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_delete(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_delete(api, mock_vector_data, mock_feature_data, feature_type):
     """Test deleting a feature for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     feature.delete()
     api.delete.assert_called_once_with(f'{layer.endpoint}features/{feature_data["id"]}/')
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_update(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_update(api, mock_vector_data, mock_feature_data, feature_type):
     """Test updating a feature for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     new_feature_data = feature.data
     new_feature_data['name'] = 'test_update'
@@ -136,22 +136,22 @@ def test_update(api, mock_vector_data, mock_feature_data, geom_type):
     assert feature.coordinates == coords
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_create_feature(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_create_feature(api, mock_vector_data, mock_feature_data, feature_type):
     """Test creating a feature for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     
     expected_request = {
         'type': 'Feature',
         'geometry': feature_data['geometry'],
-        'properties': {'name': f'test_{geom_type.lower()}'}
+        'properties': {'name': f'test_{feature_type.lower()}'}
     }
     
     api_response = {
         'type': 'Feature',
         'geometry': feature_data['geometry'],
-        'properties': {'name': f'test_{geom_type.lower()}'},
+        'properties': {'name': f'test_{feature_type.lower()}'},
         'id': feature_data['id'],
         'bbox': feature_data['bbox']
     }
@@ -168,11 +168,11 @@ def test_create_feature(api, mock_vector_data, mock_feature_data, geom_type):
     assert feature.data == api_response
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_get_feature(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_get_feature(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
 
     api.get.return_value = feature_data
     
@@ -184,11 +184,11 @@ def test_get_feature(api, mock_vector_data, mock_feature_data, geom_type):
     assert feature.data == feature_data
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_geometry(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_geometry(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature geometry for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     assert isinstance(feature.geometry, type(shape(feature_data['geometry'])))
     assert feature.geometry.area == feature_data['properties']['geom_area']
@@ -250,11 +250,11 @@ def test_geometry_import_error(api, mock_vector_data, mock_feature_data):
             feature.geometry
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_set_geometry_with_error_cases(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_set_geometry_with_error_cases(api, mock_vector_data, mock_feature_data, feature_type):
     """Test setting a feature geometry with error conditions"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     
     # Test 1: Setting invalid geometry type (not a Shapely object)
@@ -262,7 +262,7 @@ def test_set_geometry_with_error_cases(api, mock_vector_data, mock_feature_data,
         feature.geometry = "not_a_geometry"
     
     # Test 2: Setting geometry with different type than layer type
-    if geom_type != "Point":  # Only test if current type is not Point
+    if feature_type != "Point":  # Only test if current type is not Point
         point_geom = Point(1, 2)
         with pytest.raises(ValueError, match="Geometry must have the same type as the layer type"):
             feature.geometry = point_geom
@@ -273,28 +273,27 @@ def test_set_geometry_with_error_cases(api, mock_vector_data, mock_feature_data,
             feature.geometry = Point(1, 2)
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_set_geometry_success(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_set_geometry_success(api, mock_vector_data, mock_feature_data, feature_type):
     """Test setting a feature geometry for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     
     new_geometry = shape(feature_data['geometry'])
     new_geometry = translate(new_geometry, 100, 100)
     
-    assert new_geometry.geom_type == layer.layer_type.value
     feature.geometry = new_geometry
     feature.save()
     
     api.put.assert_called_once_with(f'vectorLayers/{mock_vector_data["uuid"]}/features/{feature_data["id"]}/', feature.data)
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_srid(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_srid(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature srid for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     assert feature.srid == 3857
     with pytest.raises(AttributeError):
@@ -304,38 +303,38 @@ def test_srid(api, mock_vector_data, mock_feature_data, geom_type):
     assert feature.srid == 4326
     
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_properties(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_properties(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature properties for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     assert feature.properties == feature_data['properties']
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_feature_type(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_feature_type(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature type for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
-    assert feature.feature_type == FeatureType(geom_type)
+    assert feature.feature_type == FeatureType(feature_type)
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_coordinates(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_coordinates(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature coordinates for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     assert feature.coordinates == feature_data['geometry']['coordinates']
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_length(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_length(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature length for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     assert feature.length == feature_data['properties']['geom_length']
     # api call
@@ -346,11 +345,11 @@ def test_length(api, mock_vector_data, mock_feature_data, geom_type):
     api.get.assert_called_once_with(f'{feature.endpoint}length')
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_area(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_area(api, mock_vector_data, mock_feature_data, feature_type):
     """Test getting a feature area for different geometry types"""
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data)
     assert feature.area == feature_data['properties']['geom_area']
     # api call
@@ -361,13 +360,13 @@ def test_area(api, mock_vector_data, mock_feature_data, geom_type):
     api.get.assert_called_once_with(f'{feature.endpoint}area')
 
     
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_transform_all_types(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_transform_all_types(api, mock_vector_data, mock_feature_data, feature_type):
     """Test the local transform method of Feature for all geometry types."""
     
     # Create a layer and feature for the given geometry type
-    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType(geom_type), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType.MultiPoint, data=mock_vector_data)
+    feature_data = mock_feature_data[feature_type]
     feature = Feature(layer, srid=3857, data=feature_data.copy())
 
     # Save original geometry for comparison
@@ -375,25 +374,25 @@ def test_transform_all_types(api, mock_vector_data, mock_feature_data, geom_type
 
     # Manually transform the geometry using pyproj
     transformer = Transformer.from_crs(3857, 4326, always_xy=True)
-    if geom_type == "Point":
+    if feature_type == "Point":
         x, y = original_geom.x, original_geom.y
         manual_transformed_coords = transformer.transform(x, y)
 
-    elif geom_type == "LineString":
+    elif feature_type == "LineString":
         manual_transformed_coords = [transformer.transform(x, y) for x, y in original_geom.coords]
 
-    elif geom_type == "Polygon":
+    elif feature_type == "Polygon":
         exterior = [transformer.transform(x, y) for x, y in original_geom.exterior.coords]
         interiors = [[transformer.transform(x, y) for x, y in interior.coords] for interior in original_geom.interiors]
         manual_transformed_coords = [exterior] + interiors
 
-    elif geom_type == "MultiPoint":
+    elif feature_type == "MultiPoint":
         manual_transformed_coords = [transformer.transform(point.x, point.y) for point in original_geom.geoms]
 
-    elif geom_type == "MultiLineString":
+    elif feature_type == "MultiLineString":
         manual_transformed_coords = [[transformer.transform(x, y) for x, y in line.coords] for line in original_geom.geoms]
 
-    elif geom_type == "MultiPolygon":
+    elif feature_type == "MultiPolygon":
         manual_transformed_coords = []
         for poly in original_geom.geoms:
             exterior = [transformer.transform(x, y) for x, y in poly.exterior.coords]
@@ -407,20 +406,20 @@ def test_transform_all_types(api, mock_vector_data, mock_feature_data, geom_type
 
     transformed_geom = feature.geometry
     # Compare the manually transformed coordinates with the feature's transformed coordinates
-    if geom_type == "Point":
+    if feature_type == "Point":
         trans_x, trans_y = transformed_geom.x, transformed_geom.y
         assert math.isclose(trans_x, manual_transformed_coords[0], abs_tol=1e-7)
         assert math.isclose(trans_y, manual_transformed_coords[1], abs_tol=1e-7)
     else:
         # For other types, compare the coordinates
-        assert transformed_geom.equals_exact(shape({'type': geom_type, 'coordinates': manual_transformed_coords}), 1e-7)
+        assert transformed_geom.equals_exact(shape({'type': feature_type, 'coordinates': manual_transformed_coords}), 1e-7)
 
 
-@pytest.mark.parametrize("geom_type", ["Point", "LineString", "Polygon", "MultiPoint", "MultiLineString", "MultiPolygon"])
-def test_transform_missing_data(api, mock_vector_data, mock_feature_data, geom_type):
+@pytest.mark.parametrize("feature_type", [type.value for type in FeatureType])
+def test_transform_missing_data(api, mock_vector_data, mock_feature_data, feature_type):
     """Test ValueError when feature has no data."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], layer_type=LayerType("Point"), data=mock_vector_data)
-    feature_data = mock_feature_data[geom_type]
+    feature_data = mock_feature_data[feature_type]
     del feature_data['geometry']
     feature = Feature(layer, data=feature_data)  # No geometry data
     
