@@ -288,103 +288,35 @@ def test_settings(api, mock_map_data):
     settings = map.settings
     assert settings == mock_map_data['settings']
 
+
 def test_set_settings(api, mock_map_data):
     map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
-    settings = {
-        'map_unit': 'latlng',
-        'base_map': 'OSM',
-        'flash_color': 'rgb(255,0,0)',
-        'highlight_color': 'rgb(255,0,0)',
-        'selection_color': 'rgb(255,0,0)',
-        'selectable_layers': 'ALL',
-        'calendar_type': 'gregorian',
-        'editable_layers': ['ALL'],
-        'target_layer': None,
-        'snap_tolerance': 10,
-        'snap_unit': 'pixels',
-        'snap_mode': 'both',
-        'snap_cache': 1000,
-        'controls': ['overview', 'scalebar', 'searchbar', 'legend', 'basemaps', 'coordinates', 'measurement', 'print', 'gotoxy', 'location', 'edit'],
-        'search_mode': 'both',
-        'search_layers': 'ALL',
-        'geosearch': True,
-        'remove_unused_tags': True,
-        'terrain_layer': 'terrain1',
-        'exaggeration': 1,
-        'enable_grid': True,
-        'grid_unit': 'meters',
-        'grid_width': 1000,
-        'grid_height': 1000,
-        'grid_minzoom': 0,
-        'grid_maxzoom': 20,
-        'bearing': 0,
-        'pitch': 0,
-        'center': [0, 0],
-        'zoom': 10,
-        'toc_settings': [{'name': 'vector/tehran_roads', 'title': 'tehran_roads', 'visible': True, 'sub_layers': ['main'], 'type': 'layer', 'source_type': 'vector', 'layers': [], 'popup': {'visible': True, 'theme': None, 'items': [{'id': 1749640927082, 'value': 'osm_id, code, fclass, name, ref, oneway, maxspeed, layer_, bridge, tunnel, geom_length', 'type': 'Attributes'}]}}],
-        'custom_basemaps': ['basemap1'],
-        'show_maptip_on': 'ALL',
-        'snappable_layers': 'ALL'
-    }
+    settings = map.settings
+    settings['general_settings']['base_map'] = 'osm-light'
+    settings['edit_settings']['editable_layers'] = 'test'
+    settings['snap_settings']['snap_cache'] = 1000
+    settings['search_settings']['geosearch'] = True
+    settings['marker_settings']['remvoe_unused_tags'] = False
+    settings['controls'] = ["coordinates"]
+    settings['terrain_settings']['exaggeration'] = 2
+    settings['grid_settings']['grid_width'] = 2
+    settings['view_settings']['zoom'] = 22
+    settings['toc_settings'] = ['test']
     api.put.return_value = settings
 
-    expected_settings = {
-        'general_settings': {
-            'map_unit': 'latlng',
-            'base_map': 'OSM',
-            'flash_color': 'rgb(255,0,0)',
-            'highlight_color': 'rgb(255,0,0)',
-            'selection_color': 'rgb(255,0,0)',
-            'selectable_layers': 'ALL',
-            'calendar_type': 'gregorian',
-            'custom_basemaps': ['basemap1'],
-            'show_maptip_on': 'ALL'
-        },
-        'edit_settings': {
-            'editable_layers': ['ALL'],  # Fix: Use actual behavior
-            'target_layer': None       # Fix: Use actual behavior
-        },
-        'snap_settings': {
-            'snap_tolerance': 10,
-            'snap_unit': 'pixels',
-            'snap_mode': 'both',
-            'snap_cache': 1000,
-            'snappable_layers': 'ALL'
-        },
-        'controls': ['overview', 'scalebar', 'searchbar', 'legend', 'basemaps', 'coordinates', 'measurement', 'print', 'gotoxy', 'location', 'edit'],  # Fix: Use actual controls
-        'search_settings': {
-            'search_mode': 'both',
-            'search_layers': 'ALL',
-            'geosearch': True,
-        },
-        'marker_settings': {  # Fix: Use correct key name
-            'remove_unused_tags': True,
-            'remvoe_unused_tags': True  # Fix: Include the typo if it exists in actual code
-        },
-        'terrain_settings': {
-            'terrain_layer': 'terrain1',
-            'exaggeration': 1
-        },
-        'grid_settings': {
-            'enable_grid': True,
-            'grid_unit': 'meters',
-            'grid_width': 1000,
-            'grid_height': 1000,
-            'grid_minzoom': 0,
-            'grid_maxzoom': 20
-        },
-        'view_settings': {
-            'bearing': 0,
-            'pitch': 0,
-            'center': [0, 0],
-            'zoom': 10
-        },
-        'toc_settings': [{'name': 'vector/tehran_roads', 'title': 'tehran_roads', 'visible': True, 'sub_layers': ['main'], 'type': 'layer', 'source_type': 'vector', 'layers': [], 'popup': {'visible': True, 'theme': None, 'items': [{'id': 1749640927082, 'value': 'osm_id, code, fclass, name, ref, oneway, maxspeed, layer_, bridge, tunnel, geom_length', 'type': 'Attributes'}]}}]  # Fix: Use actual toc_settings
-    }
+    map.set_settings(base_map='osm-light', 
+                        editable_layers='test', 
+                        snap_cache=1000,
+                        geosearch=True,
+                        remove_unused_tags=False,
+                        controls=["coordinates"],
+                        exaggeration=2,
+                        grid_width=2,
+                        zoom=22,
+                        toc_settings=['test'])
+    assert map.settings == settings
+    api.put.assert_called_once_with(f'{map.endpoint}settings/', settings)
 
-    map.set_settings(**settings)
-    assert map.settings == expected_settings
-    api.put.assert_called_once_with(f'{map.endpoint}settings/', expected_settings)
 
 def test_get_markers(api, mock_map_data):
     map = Map(api, uuid=mock_map_data['uuid'], data=mock_map_data)
