@@ -3,18 +3,19 @@ from urllib.parse import urlencode
 from urllib.parse import urljoin
 from unittest.mock import patch
 
+from geobox.enums import FeatureType
 from geobox.vectorlayer import VectorLayer, LayerType, InputGeomType, FileOutputFormat
 from geobox.version import VectorLayerVersion
 from geobox.field import Field, FieldType
 from geobox.view import VectorLayerView
 from geobox.user import User
 from geobox.task import Task
+from geobox.file import File
 from geobox.exception import NotFoundError
 from geobox.utils import clean_data
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_init(api, mock_vector_data, layer_type):
     """Test VectorLayer initialization."""
     layer = VectorLayer(api, 
@@ -28,16 +29,14 @@ def test_init(api, mock_vector_data, layer_type):
     assert layer.endpoint == f'{VectorLayer.BASE_ENDPOINT}{mock_vector_data["uuid"]}/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_repr(api, mock_vector_data, layer_type):
     """Test the repr method of Layer object for different geometry types"""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
     assert repr(layer) == f"VectorLayer(uuid={layer.uuid}, name={mock_vector_data['name']}, layer_type={layer_type})"
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_vectors(api, mock_vector_data, layer_type):
     """Test getting a list of layers."""
     mock_vector_data['layer_type'] = layer_type.value
@@ -61,8 +60,7 @@ def test_get_vectors(api, mock_vector_data, layer_type):
     api.get.assert_called_once_with(f'{VectorLayer.BASE_ENDPOINT}?f=json&include_settings=False&temporary=False&return_count=True&skip=0&limit=10&shared=False')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_vector(api, mock_vector_data, layer_type):
     """Test getting a specific layer."""
     mock_vector_data["layer_type"] = layer_type.value
@@ -79,8 +77,7 @@ def test_get_vector(api, mock_vector_data, layer_type):
     api.get.assert_called_once_with(f'{layer.endpoint}?f=json')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_vector_by_name(api, mock_vector_data, layer_type):
     """Test getting a specific layer."""
     mock_vector_data["layer_type"] = layer_type.value
@@ -100,8 +97,7 @@ def test_get_vector_by_name(api, mock_vector_data, layer_type):
     assert layer == None
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_vectors_by_ids(api, mock_vector_data, layer_type):
     """Test the get_mosaics_by_ids method."""
     mock_response = [{**mock_vector_data, **{'id': 1}}, {**mock_vector_data, **{'id': 2}}]
@@ -117,8 +113,7 @@ def test_get_vectors_by_ids(api, mock_vector_data, layer_type):
 
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_create_vector(api, mock_vector_data, layer_type):
     """Test creating a new layer."""
     api.post.return_value = mock_vector_data
@@ -133,7 +128,8 @@ def test_create_vector(api, mock_vector_data, layer_type):
     expected_data = {
         "name": mock_vector_data["name"],
         "layer_type": layer_type.value,
-        "has_z": mock_vector_data["has_z"]
+        "has_z": mock_vector_data["has_z"],
+        "temporary": False
     }
 
     api.post.assert_called_once_with('vectorLayers/', expected_data)
@@ -144,8 +140,7 @@ def test_create_vector(api, mock_vector_data, layer_type):
     assert layer.endpoint == f'{VectorLayer.BASE_ENDPOINT}{mock_vector_data["uuid"]}/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_update( api, mock_vector_data, layer_type):
     """Test updating layer properties."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -176,8 +171,7 @@ def test_update( api, mock_vector_data, layer_type):
     assert layer.data == api_response
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_delete(api, mock_vector_data, layer_type):
     """Test deleting a layer."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -195,8 +189,7 @@ def test_make_permanent(api, mock_vector_data):
     api.post.assert_called_once_with(f'{layer.endpoint}makePermanent/', is_json=False)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_share(api, mock_vector_data, layer_type, mock_user_data):
     """Test file sharing."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -211,8 +204,7 @@ def test_share(api, mock_vector_data, layer_type, mock_user_data):
     )
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_unshare(api, mock_vector_data, layer_type, mock_user_data):
     """Test file unsharing."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -227,8 +219,7 @@ def test_unshare(api, mock_vector_data, layer_type, mock_user_data):
     )
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_shared_users(api, mock_vector_data, layer_type, mock_user_data):
     """Test getting shared users."""
     mock_response = [
@@ -251,8 +242,7 @@ def test_get_shared_users(api, mock_vector_data, layer_type, mock_user_data):
     assert result[1].last_name == 'test 2'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_create_version(api, mock_vector_data, layer_type, mock_version_data):
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
     api.post.return_value = mock_version_data
@@ -263,16 +253,34 @@ def test_create_version(api, mock_vector_data, layer_type, mock_version_data):
     api.post.assert_called_once_with(f'{layer.endpoint}versions', {'name': 'design_version', 'display_name': 'Design Version', 'description': 'This layer represents design version.'})
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
-def test_wfs(api, mock_vector_data, layer_type):
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_get_versions(api, mock_vector_data, layer_type, mock_version_data):
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    api.get.return_value = [mock_version_data]
+    versions = layer.get_versions()
+    assert len(versions) == 1
+    assert versions[0].uuid == mock_version_data['uuid']
+    assert versions[0].data == mock_version_data
+    api.get.assert_called_once_with(f'vectorLayerVersions/?layer_id={layer.id}&f=json&return_count=False&skip=0&limit=10&shared=False')
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_wfs_access_token(api, mock_vector_data, layer_type):
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
     wfs_url = layer.wfs
     assert wfs_url == f'{api.base_url}{layer.endpoint}wfs/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_wfs_apikey(api, mock_vector_data, layer_type):
+    api.access_token = None
+    api.apikey = '123456789'
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    wfs_url = layer.wfs
+    assert wfs_url == f'{api.base_url}{layer.endpoint}apikey:{api.apikey}/wfs/'
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_fields(api, mock_vector_data, layer_type, mock_field_data):
     """Test getting the fields of a layer."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -285,43 +293,46 @@ def test_get_fields(api, mock_vector_data, layer_type, mock_field_data):
     api.get.assert_called_once_with(f'{layer.endpoint}fields/')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_field(api, mock_vector_data, layer_type, mock_field_data):
     """Test getting the fields of a layer."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
     api.get.return_value = [mock_field_data, mock_field_data]
-    # field_id
     field = layer.get_field(field_id=mock_field_data['id'])
-
     assert type(field) == Field
     assert field.data == mock_field_data
     api.get.assert_called_once_with(f'{layer.endpoint}fields/')
 
-    # name
-    api.reset_mock()
-    api.get.return_value = [mock_field_data, mock_field_data]
-    field = layer.get_field(name=mock_field_data['name'])
 
     assert type(field) == Field
     assert field.data == mock_field_data
     api.get.assert_called_once_with(f'{layer.endpoint}fields/')
 
     # error
-    api.reset_mock()
     api.get.return_value = []
-    with pytest.raises(ValueError):
-        layer.get_field()
-
     with pytest.raises(NotFoundError):
         layer.get_field(field_id=mock_field_data['id'])
 
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_get_field_by_name(api, mock_vector_data, layer_type, mock_field_data):
+    """Test getting the fields of a layer."""
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    api.get.return_value = [mock_field_data, mock_field_data]
+    field = layer.get_field_by_name(name=mock_field_data['name'])
+
+    assert type(field) == Field
+    assert field.data == mock_field_data
+    api.get.assert_called_once_with(f'{layer.endpoint}fields/')
+
+    # error
+    api.get.return_value = []
     with pytest.raises(NotFoundError):
-        layer.get_field(name=mock_field_data['name'])
+        layer.get_field_by_name(name=mock_field_data['name'])
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_add_field(api, mock_vector_data, layer_type, mock_field_data):
     """Test adding a field to a layer."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -341,8 +352,7 @@ def test_add_field(api, mock_vector_data, layer_type, mock_field_data):
     api.post.assert_called_once_with(f'{layer.endpoint}fields/', expected_data)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_calculate_field(api, mock_vector_data, layer_type, mock_success_task_data):
     """Test calculating a field."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -353,14 +363,25 @@ def test_calculate_field(api, mock_vector_data, layer_type, mock_success_task_da
     assert isinstance(task, Task)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_calculate_field_sync(api, mock_vector_data, layer_type):
+    """Test calculating a field."""
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    api.post.return_value = {'key': 'value'}
+    response = layer.calculate_field(target_field='test_field', expression='name + "test"', q='name like "test"', bbox=[10, 20, 30, 40], bbox_srid=3857, feature_ids=[1, 2, 3], run_async=False)
+    expected_data = {'target_field': 'test_field', 'expression': 'name + "test"', 'q': 'name like "test"', 'bbox': [10, 20, 30, 40], 'bbox_srid': 3857, 'feature_ids': [1, 2, 3], 'run_async': False}
+    api.post.assert_called_once_with(urljoin(layer.endpoint, 'calculateField/'), expected_data, is_json=False)
+    assert isinstance(response, dict)
+    assert response['key'] == 'value'
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_features(api, mock_vector_data, layer_type, mock_feature_data):
     """Test getting a specific feature."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
-    layer.create_feature(geojson=mock_feature_data[layer_type.value])
+    layer.create_feature(geojson=mock_feature_data[FeatureType.Polygon.value])
     api.get.return_value = {
-        'features': [mock_feature_data[layer_type.value]],
+        'features': [mock_feature_data[FeatureType.Polygon.value]],
         'crs': {
             'properties': {
                 'name': 'EPSG:3857'
@@ -375,7 +396,7 @@ def test_get_features(api, mock_vector_data, layer_type, mock_feature_data):
         'user_id': 123,
         'skip_geometry': False,
         'return_count': False,
-        'feature_ids': [mock_feature_data[layer_type.value]['id']],
+        'feature_ids': [mock_feature_data[FeatureType.Polygon.value]['id']],
         'select_fields': "[ALL]",
         'out_srid': 3857,
         'order_by': "name",
@@ -387,10 +408,10 @@ def test_get_features(api, mock_vector_data, layer_type, mock_feature_data):
     expected_endpoint = f'vectorLayers/{mock_vector_data["uuid"]}/features/?{query_string}'
     api.get.assert_called_once_with(expected_endpoint)
     assert len(features) == 1
-    assert features[0].id == mock_feature_data[layer_type.value]['id']
+    assert features[0].id == mock_feature_data[FeatureType.Polygon.value]['id']
     assert features[0].layer == layer
-    assert features[0].data == mock_feature_data[layer_type.value]
-    assert features[0].endpoint == f'vectorLayers/{mock_vector_data["uuid"]}/features/{mock_feature_data[layer_type.value]["id"]}/'
+    assert features[0].data == mock_feature_data[FeatureType.Polygon.value]
+    assert features[0].endpoint == f'vectorLayers/{mock_vector_data["uuid"]}/features/{mock_feature_data[FeatureType.Polygon.value]["id"]}/'
     # return count
     api.get.return_value = {'count': 1}
     count = layer.get_features(return_count=True)
@@ -398,42 +419,39 @@ def test_get_features(api, mock_vector_data, layer_type, mock_feature_data):
     assert count == 1
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_feature(api, mock_vector_data, layer_type, mock_feature_data):
     """Test getting a specific feature."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
-    layer.create_feature(geojson=mock_feature_data[layer_type.value])
-    api.get.return_value = mock_feature_data[layer_type.value]
-    feature = layer.get_feature(feature_id=int(mock_feature_data[layer_type.value]['id']), out_srid=4326)
+    layer.create_feature(geojson=mock_feature_data[FeatureType.Polygon.value])
+    api.get.return_value = mock_feature_data[FeatureType.Polygon.value]
+    feature = layer.get_feature(feature_id=int(mock_feature_data[FeatureType.Polygon.value]['id']), out_srid=4326)
     
-    expected_endpoint = f'vectorLayers/{mock_vector_data["uuid"]}/features/{int(mock_feature_data[layer_type.value]["id"])}'
+    expected_endpoint = f'vectorLayers/{mock_vector_data["uuid"]}/features/{int(mock_feature_data[FeatureType.Polygon.value]["id"])}'
     api.get.assert_called_once_with(expected_endpoint)
     
     assert feature is not None
-    assert feature.id == mock_feature_data[layer_type.value]['id']
+    assert feature.id == mock_feature_data[FeatureType.Polygon.value]['id']
     assert feature.layer == layer
     assert feature.srid == 4326
-    assert feature.data == mock_feature_data[layer_type.value]
-    assert feature.endpoint == f'vectorLayers/{mock_vector_data["uuid"]}/features/{mock_feature_data[layer_type.value]["id"]}/'
+    assert feature.data == mock_feature_data[FeatureType.Polygon.value]
+    assert feature.endpoint == f'vectorLayers/{mock_vector_data["uuid"]}/features/{mock_feature_data[FeatureType.Polygon.value]["id"]}/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_create_feature(api, mock_vector_data, layer_type, mock_feature_data):
     """Test creating a new feature."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
-    api.post.return_value = mock_feature_data[layer_type.value]
-    feature = layer.create_feature(geojson=mock_feature_data[layer_type.value])
+    api.post.return_value = mock_feature_data[FeatureType.Polygon.value]
+    feature = layer.create_feature(geojson=mock_feature_data[FeatureType.Polygon.value])
     assert feature is not None
-    assert feature.id == mock_feature_data[layer_type.value]['id']
+    assert feature.id == mock_feature_data[FeatureType.Polygon.value]['id']
     assert feature.layer == layer
-    assert feature.data == mock_feature_data[layer_type.value]
-    assert feature.endpoint == f'vectorLayers/{mock_vector_data["uuid"]}/features/{mock_feature_data[layer_type.value]["id"]}/'
+    assert feature.data == mock_feature_data[FeatureType.Polygon.value]
+    assert feature.endpoint == f'vectorLayers/{mock_vector_data["uuid"]}/features/{mock_feature_data[FeatureType.Polygon.value]["id"]}/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_delete_features(api, mock_vector_data, layer_type, mock_feature_data, mock_success_task_data):
     """Test deleting a specific feature."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -442,7 +460,7 @@ def test_delete_features(api, mock_vector_data, layer_type, mock_feature_data, m
         'q': "name like 'test'",
         'bbox': [10, 20, 30, 40],
         'bbox_srid': 3857,
-        'feature_ids': [mock_feature_data[layer_type.value]['id']],
+        'feature_ids': [mock_feature_data[FeatureType.Polygon.value]['id']],
         'run_async': True,
         'user_id': 123
     }
@@ -453,14 +471,34 @@ def test_delete_features(api, mock_vector_data, layer_type, mock_feature_data, m
     api.post.assert_called_once_with(expected_endpoint, params, is_json=False)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_delete_features_sync(api, mock_vector_data, layer_type, mock_feature_data):
+    """Test deleting a specific feature."""
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    api.post.return_value = {'key': 'value'}
+    params = {
+        'q': "name like 'test'",
+        'bbox': [10, 20, 30, 40],
+        'bbox_srid': 3857,
+        'feature_ids': [mock_feature_data[FeatureType.Polygon.value]['id']],
+        'run_async': False,
+        'user_id': 123
+    }
+    response = layer.delete_features(**params)
+    assert isinstance(response, dict)
+    assert response['key'] == 'value'
+    expected_endpoint = f'vectorLayers/{mock_vector_data["uuid"]}/deleteFeatures/'
+    api.post.assert_called_once_with(expected_endpoint, params, is_json=False)
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_import_features(api, mock_vector_data, layer_type, mock_success_task_data, mock_file_data):
     """Test importing features."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    file = File(api, mock_file_data['uuid'], mock_file_data)
     api.post.return_value = {'task_id': mock_success_task_data['id']}
     api.get.return_value = mock_success_task_data
-    task = layer.import_features(file_uuid=mock_file_data['uuid'], input_geom_type=InputGeomType.POINT, input_layer_name='test-layer', input_dataset='test-dataset', user_id=123, input_srid=3857, file_encoding='utf-8', replace_domain_codes_by_values=True, report_errors=True)
+    task = layer.import_features(file=file, input_geom_type=InputGeomType.POINT, input_layer_name='test-layer', input_dataset='test-dataset', user_id=123, input_srid=3857, file_encoding='utf-8', replace_domain_codes_by_values=True, report_errors=True)
     expected_data = {
         'file_uuid': mock_file_data['uuid'],
         'input_layer': 'test-layer',
@@ -476,8 +514,7 @@ def test_import_features(api, mock_vector_data, layer_type, mock_success_task_da
     assert isinstance(task, Task)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_export_features(api, mock_vector_data, layer_type, mock_success_task_data):
     """Test exporting features."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -501,8 +538,31 @@ def test_export_features(api, mock_vector_data, layer_type, mock_success_task_da
     assert isinstance(task, Task)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_export_features_sync(api, mock_vector_data, layer_type):
+    """Test exporting features."""
+    layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    api.post.return_value = {'key': 'value'}
+    response = layer.export_features(out_filename='test-file-name', out_format=FileOutputFormat.Shapefile, replace_domain_codes_by_values=True, run_async=False, bbox=[10, 20, 30, 40], out_srid=3857, zipped=True, feature_ids=[1, 2, 3], bbox_srid=3857, q='name like "test"', fields=['name', 'description'])
+    expected_data = {
+        'replace_domain_codes_by_values': True,
+        'out_format': 'Shapefile',
+        'run_async': False,
+        'bbox': [10, 20, 30, 40],
+        'out_srid': 3857,
+        'zipped': True,
+        'feature_ids': [1, 2, 3],
+        'bbox_srid': 3857,
+        'q': 'name like "test"',
+        'fields': ['name', 'description'],
+        'out_filename': 'test-file-name'
+    }
+    api.post.assert_called_once_with(f"{layer.endpoint}export/", expected_data, is_json=False)
+    assert isinstance(response, dict)
+    assert response['key'] == 'value'
+
+
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_create_view(api, mock_vector_data, layer_type, mock_view_data):
     """Test creating a new view."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -531,8 +591,7 @@ def test_create_view(api, mock_vector_data, layer_type, mock_view_data):
     assert isinstance(view.vector_layer, VectorLayer)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_tile(api, mock_vector_data, layer_type):
     """Test getting a vector tile."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -540,8 +599,7 @@ def test_get_tile(api, mock_vector_data, layer_type):
     assert endpoint == f'{layer.BASE_ENDPOINT}{layer.endpoint}tiles/3/1/2.pbf'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_tile_json(api, mock_vector_data, layer_type):
     """Test getting a vector tile JSON."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -551,8 +609,7 @@ def test_get_tile_json(api, mock_vector_data, layer_type):
     assert result == {'tile': 'value'}
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_settings(api, mock_vector_data, layer_type):
     """Test getting the settings of a layer."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -562,11 +619,35 @@ def test_settings(api, mock_vector_data, layer_type):
     assert settings == {'settings': 'value'}
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_set_settings(api, mock_vector_data, layer_type):
     """Test setting the settings of a layer."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
+    api.get.return_value = {
+        "general_settings": {
+            "title_field": None,
+            "domain_display_type": "Value",
+            "allow_export": True
+        },
+        "edit_settings": {
+            "editable": True,
+            "edit_geometry": True,
+            "editable_attributes": "[ALL]",
+            "allow_insert": True,
+            "allow_delete": True
+        },
+        "tile_settings": {
+            "min_zoom": 0,
+            "max_zoom": 24,
+            "max_features": 65536,
+            "filter_features": True,
+            "fields": [
+            "id"
+            ],
+            "use_cache": True,
+            "cache_until_zoom": 17
+        }
+        }
     settings = {
         'title_field': 'name',
         'domain_display_type': ' value',
@@ -613,8 +694,7 @@ def test_set_settings(api, mock_vector_data, layer_type):
     api.put.assert_called_once_with(f'{layer.endpoint}settings/', expected_data)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_seed_cache(api, mock_vector_data, layer_type, mock_success_task_data):
     """Test caching a seed."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -633,8 +713,7 @@ def test_seed_cache(api, mock_vector_data, layer_type, mock_success_task_data):
         layer.seed_cache()
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_clear_cache(api, mock_vector_data, layer_type):
     """Test clearing the cache."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -642,8 +721,7 @@ def test_clear_cache(api, mock_vector_data, layer_type):
     api.post.assert_called_once_with(f'{layer.endpoint}cache/clear/')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_cache_size(api, mock_vector_data, layer_type):
     """Test getting the size of the cache."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -653,8 +731,7 @@ def test_cache_size(api, mock_vector_data, layer_type):
     assert size == 1024
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_update_stats(api, mock_vector_data, layer_type):
     """Test updating the stats."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
@@ -662,8 +739,7 @@ def test_update_stats(api, mock_vector_data, layer_type):
     api.post.assert_called_once_with(f'{layer.endpoint}updateStats/')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_prune_edited_areas(api, mock_vector_data, layer_type):
     """Test pruning the edited areas."""
     layer = VectorLayer(api, uuid=mock_vector_data['uuid'], data=mock_vector_data, layer_type=layer_type)
