@@ -1,17 +1,18 @@
 import pytest
 from urllib.parse import urljoin, urlencode
 
+from geobox.enums import FeatureType
 from geobox.user import User
 from geobox.view import VectorLayerView
 from geobox.vectorlayer import VectorLayer, LayerType, FileOutputFormat, InputGeomType
 from geobox.field import Field, FieldType
 from geobox.exception import NotFoundError
 from geobox.task import Task
+from geobox.file import File
 from geobox.utils import clean_data
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_init(api, mock_view_data, layer_type):
     """Test VectorLayerView initialization."""
     view = VectorLayerView(
@@ -27,8 +28,7 @@ def test_init(api, mock_view_data, layer_type):
     assert view.endpoint == f'{VectorLayerView.BASE_ENDPOINT}{view.uuid}/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_repr(api, mock_view_data, layer_type):
     """Test the repr method of VectorLayerView object"""
     view = VectorLayerView(
@@ -40,8 +40,7 @@ def test_repr(api, mock_view_data, layer_type):
     assert repr(view) == f"VectorLayerView(uuid={view.uuid}, name={mock_view_data['name']}, layer_type={layer_type})"
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_vector_layer(api, mock_view_data, layer_type, mock_vector_data):
     """Test the vector_layer property."""
     view = VectorLayerView(
@@ -64,8 +63,7 @@ def test_vector_layer(api, mock_view_data, layer_type, mock_vector_data):
     assert vector_layer.uuid == mock_vector_data['uuid']
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_views(api, mock_view_data, layer_type):
     """Test getting all views."""
     view_data = {
@@ -85,8 +83,7 @@ def test_get_views(api, mock_view_data, layer_type):
     assert views[0].uuid == mock_view_data['uuid']
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_view(api, mock_view_data, layer_type):
     """Test getting a specific view."""
     view_data = {
@@ -108,8 +105,7 @@ def test_get_view(api, mock_view_data, layer_type):
     }
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_view_by_name(api, mock_view_data, layer_type):
     """Test getting a specific view by name."""
     view_data = {
@@ -134,8 +130,7 @@ def test_get_view_by_name(api, mock_view_data, layer_type):
     assert view == None
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_views_by_ids(api, mock_view_data, layer_type):
     """Test the get_mosaics_by_ids method."""
     mock_response = [{**mock_view_data, **{'id': 1}}, {**mock_view_data, **{'id': 2}}]
@@ -143,15 +138,14 @@ def test_get_views_by_ids(api, mock_view_data, layer_type):
     
     layers = VectorLayerView.get_views_by_ids(api, [1, 2])
     
-    api.get.assert_called_once_with(f'{VectorLayerView.BASE_ENDPOINT}get-views/?ids=%5B1%2C+2%5D&include_settings=False')
+    api.get.assert_called_once_with(f'{VectorLayerView.BASE_ENDPOINT}get-layers/?ids=%5B1%2C+2%5D&include_settings=False')
     assert len(layers) == 2
     assert all(isinstance(m, VectorLayerView) for m in layers)
     assert layers[0].data == {**mock_view_data, **{'id': 1}}
     assert layers[1].data == {**mock_view_data, **{'id': 2}}
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_update(api, mock_view_data, layer_type):
     """Test updating a view."""
     view = VectorLayerView(
@@ -186,8 +180,7 @@ def test_update(api, mock_view_data, layer_type):
     assert view.data == updated_data
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_delete(api, mock_view_data, layer_type):
     """Test deleting a layer."""
     view = VectorLayerView(
@@ -204,8 +197,7 @@ def test_delete(api, mock_view_data, layer_type):
     assert view.endpoint is None
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_share(api, mock_view_data, layer_type, mock_user_data):
     """Test file sharing."""
     view = VectorLayerView(
@@ -224,8 +216,7 @@ def test_share(api, mock_view_data, layer_type, mock_user_data):
         {'user_ids': [1, 2]}, is_json=False
     )
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_unshare(api, mock_view_data, layer_type, mock_user_data):
     """Test file unsharing."""
     view = VectorLayerView(
@@ -244,8 +235,7 @@ def test_unshare(api, mock_view_data, layer_type, mock_user_data):
         {'user_ids': [1, 2]}, is_json=False
     )
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_shared_users(api, mock_view_data, layer_type, mock_user_data):
     """Test getting shared users."""
     mock_response = [
@@ -273,8 +263,7 @@ def test_get_shared_users(api, mock_view_data, layer_type, mock_user_data):
     assert result[1].last_name == 'test 2'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_fields(api, mock_view_data, layer_type, mock_field_data):
     """Test getting the fields of a layer."""
     view = VectorLayerView(
@@ -292,8 +281,7 @@ def test_get_fields(api, mock_view_data, layer_type, mock_field_data):
     api.get.assert_called_once_with(f'{view.endpoint}fields/')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_field(api, mock_view_data, layer_type, mock_field_data):
     """Test getting the fields of a layer."""
     view = VectorLayerView(
@@ -303,63 +291,46 @@ def test_get_field(api, mock_view_data, layer_type, mock_field_data):
         data=mock_view_data
     )
     api.get.return_value = [mock_field_data, mock_field_data]
-    # field_id
     field = view.get_field(field_id=mock_field_data['id'])
 
     assert type(field) == Field
     assert field.data == mock_field_data
     api.get.assert_called_once_with(f'{view.endpoint}fields/')
 
-    # name
-    api.reset_mock()
-    api.get.return_value = [mock_field_data, mock_field_data]
-    field = view.get_field(name=mock_field_data['name'])
 
     assert type(field) == Field
     assert field.data == mock_field_data
     api.get.assert_called_once_with(f'{view.endpoint}fields/')
 
     # error
-    api.reset_mock()
     api.get.return_value = []
-    with pytest.raises(ValueError):
-        view.get_field()
-
     with pytest.raises(NotFoundError):
         view.get_field(field_id=mock_field_data['id'])
 
-    with pytest.raises(NotFoundError):
-        view.get_field(name=mock_field_data['name'])
 
-
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
-def test_add_field(api, mock_view_data, layer_type, mock_field_data):
-    """Test adding a field to a layer."""
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
+def test_get_field_by_name(api, mock_view_data, layer_type, mock_field_data):
+    """Test getting the fields of a layer."""
     view = VectorLayerView(
         api=api,
         uuid=mock_view_data['uuid'],
         layer_type=layer_type,
         data=mock_view_data
     )
-    api.post.return_value = mock_field_data
-    del mock_field_data['created_at']
-    field = view.add_field(name=mock_field_data['name'], data_type=FieldType.String, data=mock_field_data)
-    assert isinstance(field, Field)
-    assert field.name == mock_field_data['name']
-    assert field.data_type == FieldType.String
-    assert field.layer == view
-    assert field.endpoint == f'{view.endpoint}fields/{field.id}/'
+    api.get.return_value = [mock_field_data, mock_field_data]
+    field = view.get_field_by_name(name=mock_field_data['name'])
+
+    assert type(field) == Field
     assert field.data == mock_field_data
-    expected_data = {'id': mock_field_data['id'], 
-                        'name': mock_field_data['name'], 
-                        'datatype': mock_field_data['datatype'], 
-                        'hyperlink': mock_field_data['hyperlink']}
-    api.post.assert_called_once_with(f'{view.endpoint}fields/', expected_data)
+    api.get.assert_called_once_with(f'{view.endpoint}fields/')
+
+    # error
+    api.get.return_value = []
+    with pytest.raises(NotFoundError):
+        view.get_field_by_name(name=mock_field_data['name'])
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_calculate_field(api, mock_view_data, layer_type, mock_success_task_data):
     """Test calculating a field."""
     view = VectorLayerView(
@@ -375,8 +346,7 @@ def test_calculate_field(api, mock_view_data, layer_type, mock_success_task_data
     assert isinstance(task, Task)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_features(api, mock_view_data, layer_type, mock_feature_data):
     """Test getting a specific feature."""
     view = VectorLayerView(
@@ -385,9 +355,9 @@ def test_get_features(api, mock_view_data, layer_type, mock_feature_data):
         layer_type=layer_type,
         data=mock_view_data
     )
-    view.create_feature(geojson=mock_feature_data[layer_type.value])
+    view.create_feature(geojson=mock_feature_data[FeatureType.Polygon.value])
     api.get.return_value = {
-        'features': [mock_feature_data[layer_type.value]],
+        'features': [mock_feature_data[FeatureType.Polygon.value]],
         'crs': {
             'properties': {
                 'name': 'EPSG:3857'
@@ -402,7 +372,7 @@ def test_get_features(api, mock_view_data, layer_type, mock_feature_data):
         'user_id': 123,
         'skip_geometry': False,
         'return_count': False,
-        'feature_ids': [mock_feature_data[layer_type.value]['id']],
+        'feature_ids': [mock_feature_data[FeatureType.Polygon.value]['id']],
         'select_fields': "[ALL]",
         'out_srid': 3857,
         'order_by': "name",
@@ -414,10 +384,10 @@ def test_get_features(api, mock_view_data, layer_type, mock_feature_data):
     expected_endpoint = f'vectorLayerViews/{mock_view_data["uuid"]}/features/?{query_string}'
     api.get.assert_called_once_with(expected_endpoint)
     assert len(features) == 1
-    assert features[0].id == mock_feature_data[layer_type.value]['id']
+    assert features[0].id == mock_feature_data[FeatureType.Polygon.value]['id']
     assert features[0].layer == view
-    assert features[0].data == mock_feature_data[layer_type.value]
-    assert features[0].endpoint == f'vectorLayerViews/{mock_view_data["uuid"]}/features/{mock_feature_data[layer_type.value]["id"]}/'
+    assert features[0].data == mock_feature_data[FeatureType.Polygon.value]
+    assert features[0].endpoint == f'vectorLayerViews/{mock_view_data["uuid"]}/features/{mock_feature_data[FeatureType.Polygon.value]["id"]}/'
     # return count
     api.get.return_value = {'count': 1}
     count = view.get_features(return_count=True)
@@ -425,8 +395,7 @@ def test_get_features(api, mock_view_data, layer_type, mock_feature_data):
     assert count == 1
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_feature(api, mock_view_data, layer_type, mock_feature_data):
     """Test getting a specific feature."""
     view = VectorLayerView(
@@ -435,23 +404,22 @@ def test_get_feature(api, mock_view_data, layer_type, mock_feature_data):
         layer_type=layer_type,
         data=mock_view_data
     )
-    view.create_feature(geojson=mock_feature_data[layer_type.value])
-    api.get.return_value = mock_feature_data[layer_type.value]
-    feature = view.get_feature(feature_id=int(mock_feature_data[layer_type.value]['id']), out_srid=4326)
+    view.create_feature(geojson=mock_feature_data[FeatureType.Polygon.value])
+    api.get.return_value = mock_feature_data[FeatureType.Polygon.value]
+    feature = view.get_feature(feature_id=int(mock_feature_data[FeatureType.Polygon.value]['id']), out_srid=4326)
     
-    expected_endpoint = f'vectorLayerViews/{mock_view_data["uuid"]}/features/{int(mock_feature_data[layer_type.value]["id"])}'
+    expected_endpoint = f'vectorLayerViews/{mock_view_data["uuid"]}/features/{int(mock_feature_data[FeatureType.Polygon.value]["id"])}'
     api.get.assert_called_once_with(expected_endpoint)
     
     assert feature is not None
-    assert feature.id == mock_feature_data[layer_type.value]['id']
+    assert feature.id == mock_feature_data[FeatureType.Polygon.value]['id']
     assert feature.layer == view
     assert feature.srid == 4326
-    assert feature.data == mock_feature_data[layer_type.value]
-    assert feature.endpoint == f'vectorLayerViews/{mock_view_data["uuid"]}/features/{mock_feature_data[layer_type.value]["id"]}/'
+    assert feature.data == mock_feature_data[FeatureType.Polygon.value]
+    assert feature.endpoint == f'vectorLayerViews/{mock_view_data["uuid"]}/features/{mock_feature_data[FeatureType.Polygon.value]["id"]}/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_create_feature(api, mock_view_data, layer_type, mock_feature_data):
     """Test creating a new feature."""
     view = VectorLayerView(
@@ -460,17 +428,16 @@ def test_create_feature(api, mock_view_data, layer_type, mock_feature_data):
         layer_type=layer_type,
         data=mock_view_data
     )
-    api.post.return_value = mock_feature_data[layer_type.value]
-    feature = view.create_feature(geojson=mock_feature_data[layer_type.value])
+    api.post.return_value = mock_feature_data[FeatureType.Polygon.value]
+    feature = view.create_feature(geojson=mock_feature_data[FeatureType.Polygon.value])
     assert feature is not None
-    assert feature.id == mock_feature_data[layer_type.value]['id']
+    assert feature.id == mock_feature_data[FeatureType.Polygon.value]['id']
     assert feature.layer == view
-    assert feature.data == mock_feature_data[layer_type.value]
-    assert feature.endpoint == f'vectorLayerViews/{mock_view_data["uuid"]}/features/{mock_feature_data[layer_type.value]["id"]}/'
+    assert feature.data == mock_feature_data[FeatureType.Polygon.value]
+    assert feature.endpoint == f'vectorLayerViews/{mock_view_data["uuid"]}/features/{mock_feature_data[FeatureType.Polygon.value]["id"]}/'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_delete_features(api, mock_view_data, layer_type, mock_feature_data, mock_success_task_data):
     """Test deleting a specific feature."""
     view = VectorLayerView(
@@ -485,7 +452,7 @@ def test_delete_features(api, mock_view_data, layer_type, mock_feature_data, moc
         'q': "name like 'test'",
         'bbox': [10, 20, 30, 40],
         'bbox_srid': 3857,
-        'feature_ids': [mock_feature_data[layer_type.value]['id']],
+        'feature_ids': [mock_feature_data[FeatureType.Polygon.value]['id']],
         'run_async': True,
         'user_id': 123
     }
@@ -495,8 +462,7 @@ def test_delete_features(api, mock_view_data, layer_type, mock_feature_data, moc
     api.post.assert_called_once_with(expected_endpoint, params, is_json=False)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_import_features(api, mock_view_data, layer_type, mock_success_task_data, mock_file_data):
     """Test importing features."""
     view = VectorLayerView(
@@ -505,9 +471,10 @@ def test_import_features(api, mock_view_data, layer_type, mock_success_task_data
         layer_type=layer_type,
         data=mock_view_data
     )
+    file = File(api, mock_file_data['uuid'], mock_file_data)
     api.post.return_value = {'task_id': mock_success_task_data['id']}
     api.get.return_value = mock_success_task_data
-    task = view.import_features(file_uuid=mock_file_data['uuid'], input_geom_type=InputGeomType.POINT, input_layer_name='test-layer', input_dataset='test-dataset', user_id=123, input_srid=3857, file_encoding='utf-8', replace_domain_codes_by_values=True, report_errors=True)
+    task = view.import_features(file=file, input_geom_type=InputGeomType.POINT, input_layer_name='test-layer', input_dataset='test-dataset', user_id=123, input_srid=3857, file_encoding='utf-8', replace_domain_codes_by_values=True, report_errors=True)
     expected_data = {
         'file_uuid': mock_file_data['uuid'],
         'input_layer': 'test-layer',
@@ -523,8 +490,7 @@ def test_import_features(api, mock_view_data, layer_type, mock_success_task_data
     assert isinstance(task, Task)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_export_features(api, mock_view_data, layer_type, mock_success_task_data):
     """Test exporting features."""
     view = VectorLayerView(
@@ -553,8 +519,7 @@ def test_export_features(api, mock_view_data, layer_type, mock_success_task_data
     assert isinstance(task, Task)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_tile(api, mock_view_data, layer_type):
     """Test getting a vector tile."""
     view = VectorLayerView(
@@ -567,8 +532,7 @@ def test_get_tile(api, mock_view_data, layer_type):
     assert endpoint == f'{view.BASE_ENDPOINT}{view.endpoint}tiles/3/1/2.pbf'
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                      LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_get_tile_json(api, mock_view_data, layer_type):
     """Test getting a vector tile JSON."""
     view = VectorLayerView(
@@ -583,8 +547,7 @@ def test_get_tile_json(api, mock_view_data, layer_type):
     assert result == {'tile': 'value'}
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_settings(api, mock_view_data, layer_type):
     """Test getting the settings of a layer."""
     view = VectorLayerView(
@@ -599,8 +562,7 @@ def test_settings(api, mock_view_data, layer_type):
     assert settings == {'settings': 'value'}
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_set_settings(api, mock_view_data, layer_type):
     """Test setting the settings of a layer."""
     view = VectorLayerView(
@@ -609,6 +571,31 @@ def test_set_settings(api, mock_view_data, layer_type):
         layer_type=layer_type,
         data=mock_view_data
     )
+    api.get.return_value = {
+        "general_settings": {
+            "title_field": None,
+            "domain_display_type": "Value",
+            "allow_export": True
+        },
+        "edit_settings": {
+            "editable": True,
+            "edit_geometry": True,
+            "editable_attributes": "[ALL]",
+            "allow_insert": True,
+            "allow_delete": True
+        },
+        "tile_settings": {
+            "min_zoom": 0,
+            "max_zoom": 24,
+            "max_features": 65536,
+            "filter_features": True,
+            "fields": [
+            "id"
+            ],
+            "use_cache": True,
+            "cache_until_zoom": 17
+        }
+        }
     settings = {
         'title_field': 'name',
         'domain_display_type': ' value',
@@ -656,8 +643,7 @@ def test_set_settings(api, mock_view_data, layer_type):
     assert new_settings == expected_data
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_seed_cache(api, mock_view_data, layer_type, mock_success_task_data):
     """Test caching a seed."""
     view = VectorLayerView(
@@ -674,8 +660,7 @@ def test_seed_cache(api, mock_view_data, layer_type, mock_success_task_data):
     assert isinstance(task, Task)
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_clear_cache(api, mock_view_data, layer_type):
     """Test clearing the cache."""
     view = VectorLayerView(
@@ -688,8 +673,7 @@ def test_clear_cache(api, mock_view_data, layer_type):
     api.post.assert_called_once_with(f'{view.endpoint}cache/clear/')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_cache_size(api, mock_view_data, layer_type):
     """Test getting the size of the cache."""
     view = VectorLayerView(
@@ -704,8 +688,7 @@ def test_cache_size(api, mock_view_data, layer_type):
     assert size == 1024
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_update_stats(api, mock_view_data, layer_type):
     """Test updating the stats."""
     view = VectorLayerView(
@@ -718,8 +701,7 @@ def test_update_stats(api, mock_view_data, layer_type):
     api.post.assert_called_once_with(f'{view.endpoint}updateStats/')
 
 
-@pytest.mark.parametrize("layer_type", [LayerType.Point, LayerType.LineString, LayerType.Polygon, 
-                                        LayerType.MultiPoint, LayerType.MultiLineString, LayerType.MultiPolygon])
+@pytest.mark.parametrize("layer_type", [type for type in LayerType])
 def test_prune_edited_areas(api, mock_view_data, layer_type):
     """Test pruning the edited areas."""
     view = VectorLayerView(
